@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -51,7 +51,8 @@ namespace ipe {
     argument to allNames(), has(), and findDefinition().
   */
   enum Kind { EPen = 0, ESymbolSize, EArrowSize, EColor,
-	      EDashStyle, ETextSize, ETextStretch, ETextStyle,
+	      EDashStyle, ETextSize, ETextStretch,
+	      ETextStyle, ELabelStyle,
 	      EGridSize, EAngleSize, EOpacity, ETiling,
 	      ESymbol, EGradient, EEffect };
 
@@ -72,13 +73,14 @@ namespace ipe {
 		  EPropFArrowShape, EPropRArrowShape,
 		  EPropStrokeColor, EPropFillColor, EPropMarkShape,
 		  EPropPathMode, EPropDashStyle,
-		  EPropTextSize, EPropTextStyle,
+		  EPropTextSize, EPropTextStyle, EPropLabelStyle,
 		  EPropOpacity, EPropTiling, EPropGradient,
 		  EPropHorizontalAlignment, EPropVerticalAlignment,
 		  EPropLineJoin, EPropLineCap, EPropFillRule,
 		  EPropPinned, EPropTransformations,
 		  EPropTransformableText,
 		  EPropMinipage, EPropWidth,
+		  EPropDecoration,
   };
 
   /*! \ingroup attr */
@@ -95,7 +97,7 @@ namespace ipe {
   //! Vertical alignment.
   /*! \ingroup attr */
   enum TVerticalAlignment { EAlignBottom, EAlignBaseline,
-			    EAlignTop, EAlignVCenter };
+      EAlignTop, EAlignVCenter };
 
   //! Line join style.
   /*! \ingroup attr */
@@ -115,17 +117,18 @@ namespace ipe {
   //! Pinning status of objects.
   /*! \ingroup attr */
   enum TPinned { ENoPin = 0x00, EHorizontalPin = 0x01,
-		 EVerticalPin = 0x02, EFixedPin = 0x03 };
+      EVerticalPin = 0x02, EFixedPin = 0x03 };
 
   //! Transformations that are permitted for an object.
   /*! \ingroup attr */
   enum TTransformations { ETransformationsTranslations,
-			  ETransformationsRigidMotions,
-			  ETransformationsAffine };
+      ETransformationsRigidMotions,
+      ETransformationsAffine };
 
   //! Selection status of an object on the page
   /*! \ingroup attr */
-  enum TSelect { ENotSelected = 0, EPrimarySelected, ESecondarySelected };
+  enum TSelect { ENotSelected = 0, EPrimarySelected,
+      ESecondarySelected };
 
   // --------------------------------------------------------------------
 
@@ -367,7 +370,7 @@ namespace ipe {
     inline Attribute(int index) : iName(index) { /* nothing */ }
     explicit Attribute(bool symbolic, int index);
   private:
-    unsigned int iName;
+    std::uint32_t iName;
 
     friend class StyleSheet;
   };
@@ -400,7 +403,8 @@ namespace ipe {
     THorizontalAlignment iHorizontalAlignment;
     //! Vertical alignment of label objects.
     TVerticalAlignment iVerticalAlignment;
-    Attribute iTextStyle;       //!< Text style.
+    Attribute iTextStyle;       //!< Text style for minipages.
+    Attribute iLabelStyle;      //!< Text style for labels.
     TPinned iPinned;            //!< Pinned status.
     //! Should newly created text be transformable?
     /*! If this is false, newly created text will only allow
