@@ -159,6 +159,9 @@ namespace ipe {
     inline Vector topLeft() const { return Vector(iMin.x, iMax.y); }
     //! Return bottom right corner.
     inline Vector bottomRight() const { return Vector(iMax.x, iMin.y); }
+    //! Return center of rectangle.
+    inline Vector center() const { return (iMin + iMax) * 0.5; }
+
     //! Return width.
     double width() const { return iMax.x - iMin.x; }
     //! Return height.
