@@ -58,7 +58,7 @@ namespace ipe {
     PdfResources *takeResources();
 
   private:
-    bool getXForm(const PdfObj *xform, const PdfDict *ipeInfo);
+    bool getXForm(String key, const PdfDict *ipeInfo);
     void warn(String msg);
 
   private:
@@ -72,6 +72,7 @@ namespace ipe {
 
     const Cascade *iCascade;
     bool iXetex;
+    LatexType iLatexType;
 
     PdfFile iPdf;
 
