@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -41,6 +41,23 @@
 namespace ipe {
 
   class Painter {
+  public:
+    struct State {
+      Color iStroke;
+      Color iFill;
+      Fixed iPen;
+      String iDashStyle;
+      TLineCap iLineCap;
+      TLineJoin iLineJoin;
+      TFillRule iFillRule;
+      Color iSymStroke;
+      Color iSymFill;
+      Fixed iSymPen;
+      Fixed iOpacity;
+      Attribute iTiling;
+      Attribute iGradient;
+    };
+
   public:
     Painter(const Cascade *style);
     virtual ~Painter();
@@ -114,6 +131,10 @@ namespace ipe {
     //! Return current gradient fill.
     inline Attribute gradient() const { return iState.back().iGradient; }
 
+    //! Return full current graphics state.
+    inline const State & state() const { return iState.back(); }
+    void setState(const State &state);
+
   protected:
     virtual void doPush();
     virtual void doPop();
@@ -133,21 +154,6 @@ namespace ipe {
     void drawArcAsBezier(double alpha);
 
   protected:
-    struct State {
-      Color iStroke;
-      Color iFill;
-      Fixed iPen;
-      String iDashStyle;
-      TLineCap iLineCap;
-      TLineJoin iLineJoin;
-      TFillRule iFillRule;
-      Color iSymStroke;
-      Color iSymFill;
-      Fixed iSymPen;
-      Fixed iOpacity;
-      Attribute iTiling;
-      Attribute iGradient;
-    };
     std::list<State> iState;
     std::list<Matrix> iMatrix;
     const Cascade *iCascade;
