@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -38,6 +38,8 @@
 
 namespace ipe {
 
+  using PdfRenumber = std::unordered_map<int,int>;
+
   class PdfNull;
   class PdfBool;
   class PdfNumber;
@@ -52,31 +54,34 @@ namespace ipe {
   class PdfObj {
   public:
     virtual ~PdfObj() = 0;
-    virtual const PdfNull *null() const;
-    virtual const PdfBool *boolean() const;
-    virtual const PdfNumber *number() const;
-    virtual const PdfString *string() const;
-    virtual const PdfName *name() const;
-    virtual const PdfRef *ref() const;
-    virtual const PdfArray *array() const;
-    virtual const PdfDict *dict() const;
-    virtual void write(Stream &stream) const = 0;
-    String repr() const;
+    virtual const PdfNull *null() const noexcept;
+    virtual const PdfBool *boolean() const noexcept;
+    virtual const PdfNumber *number() const noexcept;
+    virtual const PdfString *string() const noexcept;
+    virtual const PdfName *name() const noexcept;
+    virtual const PdfRef *ref() const noexcept;
+    virtual const PdfArray *array() const noexcept;
+    virtual const PdfDict *dict() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber = nullptr,
+		       bool inflate = false) const noexcept = 0;
+    String repr() const noexcept;
   };
 
   class PdfNull : public PdfObj {
   public:
     explicit PdfNull() { /* nothing */ }
-    virtual const PdfNull *null() const;
-    virtual void write(Stream &stream) const;
+    virtual const PdfNull *null() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
   };
 
   class PdfBool : public PdfObj {
   public:
     explicit PdfBool(bool val) : iValue(val) { /* nothing */ }
-    virtual const PdfBool *boolean() const;
-    virtual void write(Stream &stream) const;
-    inline bool value() const { return iValue; }
+    virtual const PdfBool *boolean() const noexcept;
+    inline bool value() const noexcept { return iValue; }
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
   private:
     bool iValue;
   };
@@ -84,29 +89,35 @@ namespace ipe {
   class PdfNumber : public PdfObj {
   public:
     explicit PdfNumber(double val) : iValue(val) { /* nothing */ }
-    virtual const PdfNumber *number() const;
-    virtual void write(Stream &stream) const;
-    inline double value() const { return iValue; }
+    virtual const PdfNumber *number() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
+    inline double value() const noexcept { return iValue; }
   private:
     double iValue;
   };
 
   class PdfString : public PdfObj {
   public:
-    explicit PdfString(const String &val) : iValue(val) { /* nothing */ }
-    virtual const PdfString *string() const;
-    virtual void write(Stream &stream) const;
-    inline String value() const { return iValue; }
+    explicit PdfString(const String &val, bool binary=false)
+      : iBinary(binary), iValue(val) { /* nothing */ }
+    virtual const PdfString *string() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
+    inline String value() const noexcept { return iValue; }
+    String decode() const noexcept;
   private:
+    bool iBinary;
     String iValue;
   };
 
   class PdfName : public PdfObj {
   public:
     explicit PdfName(const String &val) : iValue(val) { /* nothing */ }
-    virtual const PdfName *name() const;
-    virtual void write(Stream &stream) const;
-    inline String value() const { return iValue; }
+    virtual const PdfName *name() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
+    inline String value() const noexcept { return iValue; }
   private:
     String iValue;
   };
@@ -114,9 +125,10 @@ namespace ipe {
   class PdfRef : public PdfObj {
   public:
   explicit PdfRef(int val) : iValue(val) { /* nothing */ }
-    virtual const PdfRef *ref() const;
-    virtual void write(Stream &stream) const;
-    inline int value() const { return iValue; }
+    virtual const PdfRef *ref() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
+    inline int value() const noexcept { return iValue; }
   private:
     int iValue;
   };
@@ -125,11 +137,12 @@ namespace ipe {
   public:
     explicit PdfArray() { /* nothing */ }
     ~PdfArray();
-    virtual const PdfArray *array() const;
-    virtual void write(Stream &stream) const;
+    virtual const PdfArray *array() const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
     void append(const PdfObj *);
-    inline int count() const { return iObjects.size(); }
-    const PdfObj *obj(int index, const PdfFile *file) const;
+    inline int count() const noexcept { return iObjects.size(); }
+    const PdfObj *obj(int index, const PdfFile *file) const noexcept;
   private:
     std::vector<const PdfObj *> iObjects;
   };
@@ -138,16 +151,25 @@ namespace ipe {
   public:
     explicit PdfDict() { /* nothing */ }
     ~PdfDict();
-    virtual const PdfDict *dict() const;
-    virtual void write(Stream &stream) const;
+    virtual const PdfDict *dict() const noexcept;
+    String dictRepr() const noexcept;
+    void dictWrite(Stream &stream, const PdfRenumber *renumber,
+		   bool inflate, int length) const noexcept;
+    virtual void write(Stream &stream, const PdfRenumber *renumber,
+		       bool inflate) const noexcept;
     void setStream(const Buffer &stream);
     void add(String key, const PdfObj *obj);
-    const PdfObj *get(String key, const PdfFile *file) const;
-    inline int count() const { return iItems.size(); }
-    inline String key(int index) const { return iItems[index].iKey; }
-    inline Buffer stream() const { return iStream; }
-    bool deflated() const;
-    // Buffer Inflate() const;
+    const PdfObj *get(String key, const PdfFile *file) const noexcept;
+    bool getNumber(String key, double &val, const PdfFile *file) const noexcept;
+    bool getNumberArray(String key, const PdfFile *file,
+			std::vector<double> &vals) const noexcept;
+    inline int count() const noexcept { return iItems.size(); }
+    inline String key(int index) const noexcept { return iItems[index].iKey; }
+    inline const PdfObj *value(int index) const noexcept {
+      return iItems[index].iVal; }
+    inline Buffer stream() const noexcept { return iStream; }
+    bool deflated() const noexcept;
+    Buffer inflate() const noexcept;
   private:
     struct Item {
       String iKey;
@@ -162,7 +184,8 @@ namespace ipe {
   //! A PDF lexical token.
   struct PdfToken {
     //! The various types of tokens.
-    enum TToken { EErr, EOp, EName, ENumber, EString, ETrue, EFalse, ENull,
+    enum TToken { EErr, EOp, EName, ENumber, EString, EStringBinary,
+		  ETrue, EFalse, ENull,
 		  EArrayBg, EArrayEnd, EDictBg, EDictEnd };
     //! The type of this token.
     TToken iType;
@@ -175,8 +198,8 @@ namespace ipe {
     PdfParser(DataSource &source);
 
     inline void getChar() { iCh = iSource.getChar(); ++iPos; }
-    inline bool eos() const { return (iCh == EOF); }
-    inline PdfToken token() const { return iTok; }
+    inline bool eos() const noexcept { return (iCh == EOF); }
+    inline PdfToken token() const noexcept { return iTok; }
 
     void getToken();
     PdfObj *getObject();
@@ -198,15 +221,15 @@ namespace ipe {
 
   class PdfFile {
   public:
-    PdfFile();
-    ~PdfFile();
     bool parse(DataSource &source);
-    const PdfObj *object(int num) const;
-    const PdfDict *catalog() const;
-    const PdfDict *page() const;
+    bool parseObjectStream(const PdfDict *d);
+    const PdfObj *object(int num) const noexcept;
+    const PdfDict *catalog() const noexcept;
+    const PdfDict *page() const noexcept;
+    std::unique_ptr<const PdfObj> take(int num);
   private:
-    std::map<int, const PdfObj *> iObjects;
-    const PdfDict *iTrailer;
+    std::unordered_map<int, std::unique_ptr<const PdfObj>> iObjects;
+    std::unique_ptr<const PdfDict> iTrailer;
   };
 
 } // namespace
