@@ -91,7 +91,7 @@ namespace ipe {
     inline Vector position() const { return iPos; }
 
     virtual bool setAttribute(Property prop, Attribute value);
-    virtual Attribute getAttribute(Property prop);
+    virtual Attribute getAttribute(Property prop) const noexcept;
 
     inline uint flags() const { return iFlags; }
     static uint flagsFromName(String name);
