@@ -60,16 +60,18 @@ namespace ipe {
     Angle iDir;          //!< Direction of x-axis
 
     void intersectionSnap(const Vector &pos,  Vector &fifi,
-			  const Page *page, double &snapDist) const;
+			  const Page *page, int view,
+			  double &snapDist) const noexcept;
     bool snapAngularIntersection(Vector &pos, const Line &l,
-				 const Page *page,
-				 double snapDist) const;
-    TSnapModes simpleSnap(Vector &pos, const Page *page,
-			  double snapDist, Tool *tool = 0) const;
-    TSnapModes snap(Vector &pos, const Page *page, double snapDist,
-		    Tool *tool = 0, Vector *autoOrg = 0) const;
-    Line getLine(const Vector &mouse, const Vector &base) const;
-    bool setEdge(const Vector &pos, const Page *page);
+				 const Page *page, int view,
+				 double snapDist) const noexcept;
+    TSnapModes simpleSnap(Vector &pos, const Page *page, int view,
+			  double snapDist, Tool *tool = 0) const noexcept;
+    TSnapModes snap(Vector &pos, const Page *page, int view,
+		    double snapDist, Tool *tool = 0,
+		    Vector *autoOrg = 0) const noexcept;
+    Line getLine(const Vector &mouse, const Vector &base) const noexcept;
+    bool setEdge(const Vector &pos, const Page *page, int view) noexcept;
   };
 
 } // namespace
