@@ -131,7 +131,7 @@ namespace ipe {
     const TitleStyle *titleStyle() const;
     void setTitleStyle(const TitleStyle &ts);
 
-    const PageNumberStyle *pageNumberStyle();
+    const PageNumberStyle *pageNumberStyle() const;
     void setPageNumberStyle(const PageNumberStyle &pns);
 
     void setLineCap(TLineCap s);
@@ -186,6 +186,8 @@ namespace ipe {
     inline int count() const { return iSheets.size(); }
     //! Return StyleSheet at \a index.
     inline StyleSheet *sheet(int index) { return iSheets[index]; }
+    //! Return StyleSheet at \a index.
+    inline const StyleSheet *sheet(int index) const { return iSheets[index]; }
 
     void insert(int index, StyleSheet *sheet);
     void remove(int index);
