@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ namespace ipe {
 
   class Text : public Object {
   public:
-    enum TextType { ELabel = 1, EMinipage };
+    enum TextType { ELabel, EMinipage };
 
     explicit Text();
     explicit Text(const AllAttributes &attr, String data,
@@ -71,7 +71,7 @@ namespace ipe {
     virtual void checkStyle(const Cascade *sheet, AttributeSeq &seq) const;
 
     virtual bool setAttribute(Property prop, Attribute value);
-    virtual Attribute getAttribute(Property prop);
+    virtual Attribute getAttribute(Property prop) const noexcept;
 
   private:
     void quadrilateral(const Matrix &m, Vector v[4]) const;
@@ -116,15 +116,14 @@ namespace ipe {
     void setText(String text);
 
     struct XForm {
-      unsigned long int iRefCount;
-      Buffer iStream;
+      int iRefCount;
       Rect iBBox;
       int iDepth;
-      std::vector<int> iFonts;
-      double iStretch;
+      float iStretch;
+      String iName;
+      Vector iTranslation;
     };
 
-    bool isInternal() const { return iType == 0; }
     void setXForm(XForm *xform) const;
     inline const XForm *getXForm() const;
 
