@@ -79,6 +79,20 @@ AppUiBase::AppUiBase(lua_State *L0, int model)
     iToolbarScale = (int) lua_tointeger(L, -1);
   lua_pop(L, 1); // toolbar_scale
 
+  iUiGap = 0;
+  lua_getfield(L, -1, "ui_gap");
+  if (lua_isnumber(L, -1))
+    iUiGap = (int) lua_tointeger(L, -1);
+  lua_pop(L, 1); // ui_gap
+
+  lua_getfield(L, -1, "mini_edit");
+  isMiniEdit = lua_toboolean(L, -1);
+  lua_pop(L, 1); // mini_edit
+
+  lua_getfield(L, -1, "left_dock_floats");
+  iLeftDockFloats = lua_toboolean(L, -1);
+  lua_pop(L, 1); // left_dock_floats
+
   iScalings.push_back(1);
   lua_getfield(L, -1, "scale_factors");
   if (lua_istable(L, -1)) {
