@@ -188,6 +188,9 @@ protected:
   double iMouseFactor;
   int iUiScale;
   int iToolbarScale;
+  int iUiGap;
+  bool isMiniEdit;
+  bool iLeftDockFloats;
   bool isInkMode;
 };
 
