@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -46,87 +46,6 @@ using namespace ipelua;
 
 // --------------------------------------------------------------------
 
-#if 0
-QIcon prefsIcon(String name)
-{
-  String dir = ipeIconDirectory();
-  if (Platform::fileExists(dir + name + ".png"))
-    return QIcon(QIpe(dir + name + ".png"));
-  else
-    return QIcon();
-}
-
-QPixmap prefsPixmap(String name)
-{
-  return QPixmap(QIpe(ipeIconDirectory() + name + ".png"));
-}
-
-QIcon prefsColorIcon(Color color)
-{
-  QPixmap pixmap(SIZE, SIZE);
-  pixmap.fill(QIpe(color));
-  return QIcon(pixmap);
-}
-#endif
-
-// --------------------------------------------------------------------
-
-#if 0
-QAction *AppUi::findAction(const char *name) const
-{
-  std::map<String, QAction*>::const_iterator it = iActions.find(name);
-  if (it != iActions.end())
-    return it->second;
-  else
-    return 0;
-}
-
-void AppUi::addItem(QMenu *m, const QString &title, const char *name)
-{
-  QAction *a = new QAction(title, this);
-  lua_getglobal(L, "shortcuts");
-  lua_getfield(L, -1, name);
-  if (lua_isstring(L, -1)) {
-    QString s = lua_tostring(L, -1);
-    a->setShortcut(QKeySequence(s));
-    QString tt = title + " [" + s + "]";
-    a->setToolTip(tt);
-  } else if (lua_istable(L, -1)) {
-    int no = lua_objlen(L, -1);
-    QList<QKeySequence> kl;
-    QString prim;
-    for (int i = 1; i <= no; ++i) {
-      lua_rawgeti(L, -1, i);
-      if (lua_isstring(L, -1)) {
-	QString s = lua_tostring(L, -1);
-	kl.append(QKeySequence(s));
-	if (prim.isEmpty())
-	  prim = s;
-      }
-      lua_pop(L, 1); // pop string
-    }
-    a->setShortcuts(kl);
-    QString tt = title + " [" + prim + "]";
-    a->setToolTip(tt);
-  }
-  a->setIcon(prefsIcon(name));
-  lua_pop(L, 2);
-  m->addAction(a);
-  if (m == iMenu[EModeMenu]) {
-    a->setCheckable(true);
-    a->setActionGroup(iModeActionGroup);
-    iObjectTools->addAction(a);
-  }
-  if (String(name).find('|') >= 0) {
-    // selector item
-    a->setCheckable(true);
-  }
-  connect(a, SIGNAL(triggered()), iActionMap, SLOT(map()));
-  iActionMap->setMapping(a, name);
-  iActions[name] = a;
-}
-#endif
-
 static String change_mnemonic(const char *s)
 {
   int n = strlen(s);
@@ -300,7 +219,6 @@ void AppUi::setComboCurrent(int sel, int idx)
 
 void AppUi::setButtonColor(int sel, Color color)
 {
-  // ipeDebug("Changing color for %d");
   // TODO
 }
 
@@ -338,20 +256,6 @@ void AppUi::setNotes(String notes)
 {
 }
 
-int AppUi::actionId(const char *name) const
-{
-  for (int i = 0; i < int(iActions.size()); ++i) {
-    if (iActions[i].name == name)
-      return i;
-  }
-  return -1;
-}
-
-int AppUi::actionAlwaysOn(const char *name) const
-{
-  return true; // TODO
-}
-
 // only used for snapXXX and grid_size
 bool AppUi::actionState(const char *name)
 {
@@ -382,6 +286,15 @@ void AppUi::setToolVisible(int m, bool vis)
 
 // --------------------------------------------------------------------
 
+int AppUi::actionId(const char *name) const
+{
+  for (int i = 0; i < int(iActions.size()); ++i) {
+    if (iActions[i].name == name)
+      return i;
+  }
+  return -1;
+}
+
 WINID AppUi::windowId()
 {
   return iWindow;
@@ -439,7 +352,6 @@ int AppUi::clipboard(lua_State *L)
 
 void AppUi::action(String name)
 {
-  ipeDebug("action %s", name.z());
   luaAction(name);
 }
 
