@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -51,8 +51,6 @@ public:
   virtual void setNumbers(String vno, bool vm, String pno, bool pm);
   virtual void setNotes(String notes);
 
-  virtual int actionId(const char *name) const;
-  virtual int actionAlwaysOn(const char *name) const;
   virtual WINID windowId();
   virtual void closeWindow();
   virtual bool actionState(const char *name);
@@ -70,6 +68,7 @@ public:
   virtual int setClipboard(lua_State *L);
 
 private:
+  int actionId(const char *name) const;
   virtual void addRootMenu(int id, const char *name);
   void addItem(GtkMenuShell *shell, const char *title, const char *name);
   virtual void addItem(int id, const char *title, const char *name);
