@@ -296,6 +296,8 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
 	  SLOT(moveToLayerAction(QAction *)));
   connect(iTextStyleMenu, SIGNAL(triggered(QAction *)),
 	  SLOT(textStyleAction(QAction *)));
+  connect(iLabelStyleMenu, SIGNAL(triggered(QAction *)),
+	  SLOT(labelStyleAction(QAction *)));
   connect(iGridSizeMenu, SIGNAL(triggered(QAction *)),
 	  SLOT(gridSizeAction(QAction *)));
   connect(iAngleSizeMenu, SIGNAL(triggered(QAction *)),
@@ -498,6 +500,8 @@ AppUi::AppUi(lua_State *L0, int model, Qt::WindowFlags f)
 	  this, SLOT(aboutToShowMoveToLayerMenu()));
   connect(iTextStyleMenu, SIGNAL(aboutToShow()),
 	  this, SLOT(aboutToShowTextStyleMenu()));
+  connect(iLabelStyleMenu, SIGNAL(aboutToShow()),
+	  this, SLOT(aboutToShowLabelStyleMenu()));
   connect(iGridSizeMenu, SIGNAL(aboutToShow()),
 	  this, SLOT(aboutToShowGridSizeMenu()));
   connect(iAngleSizeMenu, SIGNAL(aboutToShow()),
@@ -557,21 +561,31 @@ void AppUi::moveToLayerAction(QAction *a)
   action(String("movetolayer-") + IpeQ(a->text()));
 }
 
-void AppUi::aboutToShowTextStyleMenu()
+void AppUi::aboutToShowStyleMenu(Kind kind, MENUHANDLE menu, String current)
 {
   AttributeSeq seq;
-  iCascade->allNames(ETextStyle, seq);
-  iTextStyleMenu->clear();
+  iCascade->allNames(kind, seq);
+  menu->clear();
   for (uint i = 0; i < seq.size(); ++i) {
     String s = seq[i].string();
-    QAction *a = new QAction(QIpe(s), iTextStyleMenu);
+    QAction *a = new QAction(QIpe(s), menu);
     a->setCheckable(true);
-    if (s == iAll.iTextStyle.string())
+    if (s == current)
       a->setChecked(true);
-    iTextStyleMenu->addAction(a);
+    menu->addAction(a);
   }
 }
 
+void AppUi::aboutToShowTextStyleMenu()
+{
+  aboutToShowStyleMenu(ETextStyle, iTextStyleMenu, iAll.iTextStyle.string());
+}
+
+void AppUi::aboutToShowLabelStyleMenu()
+{
+  aboutToShowStyleMenu(ELabelStyle, iLabelStyleMenu, iAll.iLabelStyle.string());
+}
+
 void AppUi::aboutToShowGridSizeMenu()
 {
   iGridSizeMenu->clear();
@@ -603,6 +617,11 @@ void AppUi::textStyleAction(QAction *a)
   action(String("textstyle|") + IpeQ(a->text()));
 }
 
+void AppUi::labelStyleAction(QAction *a)
+{
+  action(String("labelstyle|") + IpeQ(a->text()));
+}
+
 void AppUi::gridSizeAction(QAction *a)
 {
   action(String("gridsize|") + IpeQ(a->text()));
