@@ -97,6 +97,7 @@ public slots:
   void selectLayerAction(QAction *a);
   void moveToLayerAction(QAction *a);
   void textStyleAction(QAction *a);
+  void labelStyleAction(QAction *a);
   void gridSizeAction(QAction *a);
   void angleSizeAction(QAction *a);
 
@@ -114,6 +115,7 @@ public slots:
   void aboutToShowSelectLayerMenu();
   void aboutToShowMoveToLayerMenu();
   void aboutToShowTextStyleMenu();
+  void aboutToShowLabelStyleMenu();
   void aboutToShowGridSizeMenu();
   void aboutToShowAngleSizeMenu();
 
@@ -127,6 +129,7 @@ private:
   void addEdit(const char *name);
   QIcon prefsColorIcon(Color color);
   QPixmap prefsPixmap(String name);
+  void aboutToShowStyleMenu(Kind kind, MENUHANDLE menu, String current);
 
 private:
   virtual void addRootMenu(int id, const char *name) override;
