@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -104,13 +104,6 @@ void LayerBox::mouseReleaseEvent(QMouseEvent *ev)
 
 // --------------------------------------------------------------------
 
-#if defined(__APPLE__)
-// it doesn't hurt even if there is no actual retina display
-#define RETINA (2)
-#else
-#define RETINA (1)
-#endif
-
 #if QT_VERSION < 0x050000
 PathView::PathView(QWidget* parent, Qt::WFlags f) : QWidget(parent, f)
 #else
@@ -130,8 +123,8 @@ void PathView::set(const AllAttributes &all, Cascade *sheet)
 void PathView::paintEvent(QPaintEvent *ev)
 {
   QSize s = size();
-  int w = RETINA * s.width();
-  int h = RETINA * s.height();
+  int w = s.width();
+  int h = s.height();
 
   cairo_surface_t *sf = cairo_image_surface_create(CAIRO_FORMAT_RGB24, w, h);
   cairo_t *cc = cairo_create(sf);
@@ -141,7 +134,7 @@ void PathView::paintEvent(QPaintEvent *ev)
 
   if (iCascade) {
     cairo_translate(cc, 0, h);
-    double zoom = RETINA * 2.0;
+    double zoom = w / 70.0;
     cairo_scale(cc, zoom, -zoom);
     Vector v0 = (1.0/zoom) * Vector(0.1 * w, 0.5 * h);
     Vector v1 = (1.0/zoom) * Vector(0.7 * w, 0.5 * h);
@@ -185,9 +178,7 @@ void PathView::paintEvent(QPaintEvent *ev)
   qPainter.begin(this);
   QRect r = ev->rect();
   QImage bits(cairo_image_surface_get_data(sf), w, h, QImage::Format_RGB32);
-  QRect source(RETINA * r.left(), RETINA * r.top(),
-	       RETINA * r.width(), RETINA * r.height());
-  qPainter.setRenderHint(QPainter::SmoothPixmapTransform, true);
+  QRect source(r.left(), r.top(), r.width(), r.height());
   qPainter.drawImage(r, bits, source);
   qPainter.end();
   cairo_surface_destroy(sf);
@@ -195,7 +186,7 @@ void PathView::paintEvent(QPaintEvent *ev)
 
 QSize PathView::sizeHint() const
 {
-  return QSize(120, 40);
+  return QSize(120, size().width() / 8.0);
 }
 
 void PathView::mousePressEvent(QMouseEvent *ev)
