@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -68,30 +68,6 @@ private:
 
 // --------------------------------------------------------------------
 
-#if 0
-class PageSorter : public QListWidget {
-  Q_OBJECT
-
-public:
-  PageSorter(Document *doc, int width, QWidget *parent = 0);
-
-  int pageAt(int r) const;
-
-public slots:
-  void deletePages();
-  void cutPages();
-  void insertPages();
-
-private:
-  virtual void contextMenuEvent(QContextMenuEvent *event);
-
-private:
-  Document *iDoc;
-  QList<QListWidgetItem *> iCutList;
-  int iActionRow;
-};
-#endif
-
 extern void ipe_init_controls(HINSTANCE hInstance);
 
 // --------------------------------------------------------------------
