@@ -51,6 +51,7 @@ function MODEL:paction(a1)
   -- print("MODEL:paction(" .. a .. ")")
   if a:sub(1,5) == "mode_" then
     self.mode = a:sub(6)
+    self.ui:setInkMode(self.mode == "ink")
     if prefs.no_ink_snap then
       -- disable snapping in ink mode
       if self.mode == "ink" then
@@ -71,10 +72,6 @@ function MODEL:paction(a1)
       end
       self:setSnap()
     end
-    if prefs.no_ink_highlight then
-      self.ui:setFifiVisible(self.mode ~= "ink")
-      self.ui:setSelectionVisible(self.mode ~= "ink")
-    end
   elseif a:sub(1,4) == "snap" then
     self.snap[a] = self.ui:actionState(a)
     self:setSnap()
@@ -102,6 +99,13 @@ function MODEL:paction(a1)
   end
 end
 
+local function has_text(page)
+  for i,obj,sel,layer in page:objects() do
+    if sel and obj:type() == "text" then return true end
+  end
+  return false
+end
+
 -- Attribute selector
 function MODEL:selector(prop, value)
   if prop == "gridsize" or prop == "anglesize" then
@@ -128,7 +132,7 @@ function MODEL:selector(prop, value)
   self.ui:setAttributes(self.doc:sheets(), self.attributes)
   if self:page():hasSelection() then
     self:setAttribute(prop, value)
-    if prop == "textsize" then
+    if prop == "textsize" or has_text(self:page()) then
       self:autoRunLatex()
     end
   end
@@ -797,9 +801,9 @@ end
 ----------------------------------------------------------------------
 
 function action_manual()
-  local url = "file:///" .. config.docdir .. "/manual.html"
+  local url = config.docdir .. "/manual.html"
   if ipeui.startBrowser then
-    if not ipeui.startBrowser(url) then
+    if not ipeui.startBrowser("file:///" ..  url) then
       messageBox(nil, "warning", "Manual not available!", url)
     end
   else
@@ -922,6 +926,88 @@ function MODEL:action_set_direction()
   self.ui:update()
 end
 
+local function find_arc_under_point_in_object(obj, m, pos)
+  if obj:type() == "group" then
+    local m1 = m * obj:matrix()
+    for i = 1,obj:count() do
+      local t = obj:elementType(i)
+      if t == "path" or t == "group" then
+	local obj1 = obj:element(i)
+	local r = ipe.Rect()
+	obj1:addToBBox(r, m1)
+	if r:contains(pos) then
+	  local arc = find_arc_under_point_in_object(obj1, m1, pos)
+	  if arc then return arc end
+	end
+      end
+    end
+  elseif obj:type() == "path" then
+    local m1 = m * obj:matrix()
+    local shape = obj:shape()
+    for _, sp in ipairs(shape) do
+      if sp.type == "ellipse" then
+	local m2 = m1 * sp[1]
+	local post = m2:inverse() * pos
+	if math.abs(post:sqLen() - 1.0) < 1e-3 then
+	  return m2
+	end
+      elseif sp.type == "curve" then
+	for i = 1,#sp do
+	  if sp[i].type == "arc" then
+	    local m2 = m1 * sp[i].arc:matrix()
+	    local post = m2:inverse() * pos
+	    if math.abs(post:sqLen() - 1.0) < 1e-3 then
+	      return m2
+	    end
+	  end
+	end
+      end
+    end
+  end
+end
+
+local function find_arc_under_point(p, pos)
+  local m = ipe.Matrix()
+  for i, obj, sel, layer in p:objects() do
+    if p:bbox(i):contains(pos) then
+      local arc = find_arc_under_point_in_object(obj, m, pos)
+      if arc then return arc end
+    end
+  end
+end
+
+function MODEL:action_set_tangent_direction()
+  local p = self:page()
+  local pos, dir = p:findEdge(self.vno, self.ui:unsnappedPos())
+  if not pos then
+    self.ui:explain("Mouse is not on an edge")
+    return false
+  end
+  local arc = find_arc_under_point(p, pos)
+  if not arc then
+    self.ui:explain("Mouse is not on a circular arc")
+    return false
+  end
+  local p = arc:inverse() * self.snap.origin
+  local d = p:len()
+  if d < 1.0 then
+    self.ui:explain("Origin is inside the ellipse")
+    return false
+  end
+  local r = math.sqrt(d * d - 1.0)
+  local c = ipe.Arc(ipe.Matrix(r, 0, 0, r, p.x, p.y))
+  local qs = c:intersect(ipe.Arc(ipe.Matrix()))
+  if #qs ~= 2 then return false end
+  local pos1 = arc:inverse() * pos
+  local q = qs[1]
+  if (pos1 - qs[2]):sqLen() < (pos1 - q):sqLen() then q = qs[2] end
+  self.snap.with_axes = true;
+  self.snap.orientation = (arc * q - self.snap.origin):angle()
+  self.ui:setSnap(self.snap)
+  self.ui:update()
+  return true
+end
+
 function MODEL:action_reset_direction()
   self.snap.orientation = 0
   self:setSnap()
@@ -929,7 +1015,7 @@ function MODEL:action_reset_direction()
 end
 
 function MODEL:setLine()
-  local origin, dir = self:page():findEdge(self.ui:simpleSnapPos())
+  local origin, dir = self:page():findEdge(self.vno, self.ui:unsnappedPos())
   if not origin then
     self.ui:explain("Mouse is not on an edge")
     return false
@@ -2251,7 +2337,7 @@ end
 ----------------------------------------------------------------------
 
 function MODEL:action_document_properties()
-  local engines = { "default", "pdftex", "xetex" } -- "luatex" }
+  local engines = { "default", "pdftex", "xetex", "luatex" }
   local p = self.doc:properties()
   local d = ipeui.Dialog(self.ui:win(), "Ipe document properties")
   d:add("label1", "label", { label="Title"}, 1, 1)
