@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -889,6 +889,7 @@ end
 
 function EDITTOOL:mouseButton(button, modifiers, press)
   self.moving = false
+  if modifiers.control and button == 1 then button = 2 end
   if self.scissor and press and button == 1 then
     self[self.cutter](self)
     self.scissor = nil
@@ -947,11 +948,11 @@ end
 
 function EDITTOOL:explain()
   if self.scissor then
-    self.model.ui:explain("Left: cut | Right or double-left: menu | "
-			  .. "Ctrl+Z: undo | Space: accept")
+    self.model.ui:explain("Left: cut | Right, ctrl-left, or double-left: menu"
+			  .. " | Ctrl+Z: undo | Space: accept")
   else
-    self.model.ui:explain("Left: move | Right or double-left: menu | "
-			  .. "Ctrl+Z: undo | Space: accept")
+    self.model.ui:explain("Left: move | Right, ctrl-left, or double-left: menu"
+			  .. " | Ctrl+Z: undo | Space: accept")
   end
 end
 
@@ -1060,22 +1061,38 @@ function MODEL:saction_join()
     return
   end
 
+  local found_endpoint = false
   -- match up endpoints
   if not findPartner(l, 1, 2) then
     -- not found, flip l[1] and try again
     flip(l[1])
   end
-  for i = 1,#l - 1 do
+  local i = 1
+  while i < #l do
     -- invariant: l[1] .. l[i] form a chain
     local j = findPartner(l, i, i+1)
     if not j then
-      self:warning("Cannot join paths",
-		   "Unable to join paths to a single curve")
-      return
-    end
-    -- flip i+1 and j
-    if j ~= i+1 then
-      l[i+1], l[j] = l[j], l[i+1]
+      if found_endpoint then
+	self:warning("Cannot join paths",
+		     "Unable to join paths to a single curve")
+	return
+      end
+      found_endpoint = true
+      -- i is the end of the joined curve
+      local a = 1
+      local b = i
+      while a < b do
+	-- flip a and b and reverse them
+	l[a], l[b] = l[b], l[a]
+	flip(l[a]); flip(l[b])
+	a = a + 1; b = b - 1
+      end
+    else
+      -- flip i+1 and j
+      if j ~= i+1 then
+	l[i+1], l[j] = l[j], l[i+1]
+      end
+      i = i + 1
     end
   end
 
