@@ -581,11 +581,9 @@ function MODEL:saveDocument(fname)
   end
 
   -- run Latex if format is not XML
-  if fm ~= "xml" then
-    if not self:runLatex() then
-      self.ui:explain("Latex error - file not saved")
-      return
-    end
+  if fm ~= "xml" and not self:runLatex() then
+    self.ui:explain("Latex error - file not saved")
+    return
   end
 
   local props = self.doc:properties()
@@ -599,6 +597,10 @@ function MODEL:saveDocument(fname)
     return
   end
 
+  if fm == "xml" and prefs.auto_export_to_pdf then
+    self:auto_export(fname)
+  end
+
   self:markAsUnmodified()
   self.ui:explain("Saved document '" .. fname .. "'")
   self.file_name = fname
@@ -606,6 +608,19 @@ function MODEL:saveDocument(fname)
   return true
 end
 
+function MODEL:auto_export(fname)
+  if not self:runLatex() then
+    self.ui:explain("Latex error - could not export to PDF!")
+  else
+    local ename = fname:sub(1,-4) .. "pdf"
+    if not self.doc:save(ename, "pdf", { export=true } ) then
+      self:warning("Auto-exporting failed",
+		   "I could not export in PDF format to file '"
+		     .. ename .. "'.")
+    end
+  end
+end
+
 ----------------------------------------------------------------------
 
 function MODEL:autosave()
