@@ -59,8 +59,8 @@ shortcuts = {
   duplicate = "D",
   select_all = "Ctrl+A",
   join_paths = "Ctrl+J",
-  pick_properties = nil,
-  apply_properties = nil,
+  pick_properties = "Q",
+  apply_properties = "Ctrl+Q",
   insert_text_box = "F10",
   edit = "Ctrl+E",
   edit_as_xml = nil,
