@@ -1030,9 +1030,9 @@ local function collect_edges(p, box)
 	local head = curve[1][1]
 	local seg = curve[#curve]
 	local tail = seg[#seg]
-	if box:contains(head) then
+	if box:contains(m * head) then
 	  edges[#edges + 1] = { obj=obj, head=true, objno=i }
-	elseif box:contains(tail) then
+	elseif box:contains(m * tail) then
 	  edges[#edges + 1] = { obj=obj, head=false, objno=i }
 	end
       end
@@ -1127,6 +1127,7 @@ local function apply_node_mode(t, doc)
       seg[#seg] = seg[#seg] + t.translation
     end
     p[e.objno]:setShape(shape)
+    p[e.objno]:setMatrix(ipe.Matrix())
   end
 end
 
