@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -126,7 +126,7 @@ void PathView::wndPaint()
 
   if (iCascade) {
     cairo_translate(cc, 0, h);
-    double zoom = 2.0;
+    double zoom = w / 100.0;
     cairo_scale(cc, zoom, -zoom);
     Vector v0 = (1.0/zoom) * Vector(0.1 * w, 0.5 * h);
     Vector v1 = (1.0/zoom) * Vector(0.7 * w, 0.5 * h);
