@@ -156,6 +156,8 @@ void ShapeTool::draw(Painter &painter) const
   double z = 1.0 / iCanvas->zoom();
   painter.setPen(Attribute(Fixed::fromDouble(iPen)));
   painter.setStroke(Attribute(iColor));
+  painter.setLineCap(TLineCap::ERoundCap);
+  painter.setLineJoin(TLineJoin::ERoundJoin);
   painter.newPath();
   iShape.draw(painter);
   painter.drawPath(EStrokedOnly);
