@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -85,12 +85,12 @@ static int appui_setPage(lua_State *L)
   return 0;
 }
 
-static int appui_setFontPool(lua_State *L)
+static int appui_setResources(lua_State *L)
 {
   CanvasBase *canvas = check_canvas(L, 1);
   Document **d = check_document(L, 2);
-  const FontPool *fonts = (*d)->fontPool();
-  canvas->setFontPool(fonts);
+  const PdfResources *res = (*d)->resources();
+  canvas->setResources(res);
   return 0;
 }
 
@@ -124,6 +124,13 @@ static int appui_setZoom(lua_State *L)
   return 0;
 }
 
+static int appui_setSnapIndicator(lua_State *L)
+{
+  AppUiBase **ui = check_appui(L, 1);
+  (*ui)->setSnapIndicator(luaL_checkstring(L, 2));
+  return 0;
+}
+
 static int appui_pos(lua_State *L)
 {
   CanvasBase *canvas = check_canvas(L, 1);
@@ -159,6 +166,15 @@ static int appui_setFifiVisible(lua_State *L)
   return 0;
 }
 
+static int appui_setInkMode(lua_State *L)
+{
+  AppUiBase **ui = check_appui(L, 1);
+  bool ink = lua_toboolean(L, 2);
+  (*ui)->setInkMode(ink);
+  (*ui)->canvas()->setInkMode(ink);
+  return 0;
+}
+
 static int appui_setSelectionVisible(lua_State *L)
 {
   CanvasBase *canvas = check_canvas(L, 1);
@@ -235,14 +251,12 @@ static int appui_update(lua_State *L)
     else
       canvas->updateTool();
   } else {
-    /*
-    Rect *r = check_rect(L, 2);
+    ipe::Rect *r = check_rect(L, 2);
     Vector bl = canvas->userToDev(r->topLeft());
     Vector tr = canvas->userToDev(r->bottomRight());
     canvas->invalidate(int(bl.x-1), int(bl.y-1),
 		       int(tr.x - bl.x + 2),
 		       int(tr.y - bl.y + 2));
-    */
   }
   return 0;
 }
@@ -317,6 +331,7 @@ static int appui_setPretty(lua_State *L)
 
 static int appui_pantool(lua_State *L)
 {
+  ipeDebug("pantool");
   CanvasBase *canvas = check_canvas(L, 1);
   Page *page = check_page(L, 2)->page;
   int view = check_viewno(L, 3, page);
@@ -341,7 +356,7 @@ static int appui_selecttool(lua_State *L)
 static int appui_transformtool(lua_State *L)
 {
   static const char * const option_names[] = {
-    "translate", "scale", "stretch", "rotate", 0 };
+    "translate", "scale", "stretch", "rotate", "shear", 0 };
   CanvasBase *canvas = check_canvas(L, 1);
   Page *page = check_page(L, 2)->page;
   int view = check_viewno(L, 3, page);
@@ -495,13 +510,11 @@ static int appui_setClipboard(lua_State *L)
   return (*ui)->setClipboard(L);
 }
 
+// This is only used on Windows to compute the shortcuts...
 static int appui_actionInfo(lua_State *L)
 {
   AppUiBase **ui = check_appui(L, 1);
-  const char *action = luaL_checkstring(L, 2);
-  lua_pushinteger(L, (*ui)->actionId(action));
-  lua_pushboolean(L, (*ui)->actionAlwaysOn(action));
-  return 2;
+  return (*ui)->actionInfo(L);
 }
 
 static int appui_actionState(lua_State *L)
@@ -730,14 +743,16 @@ static const struct luaL_Reg appui_methods[] = {
   { "setPan", appui_setPan},
   { "zoom", appui_zoom},
   { "setZoom", appui_setZoom},
-  { "setFontPool", appui_setFontPool},
+  { "setResources", appui_setResources},
   { "pos", appui_pos},
   { "globalPos", appui_globalPos},
   { "unsnappedPos", appui_unsnappedPos},
   { "simpleSnapPos", appui_simpleSnapPos },
   { "setFifiVisible", appui_setFifiVisible},
+  { "setInkMode", appui_setInkMode },
   { "setSelectionVisible", appui_setSelectionVisible},
   { "setSnap", appui_setSnap},
+  { "setSnapIndicator", appui_setSnapIndicator},
   { "setAutoOrigin", appui_setAutoOrigin },
   { "update", appui_update},
   { "finishTool", appui_finishTool},
@@ -793,6 +808,8 @@ static int appui_constructor(lua_State *L)
   CanvasBase::Style style;
   style.pretty = false;
   style.paperColor = Color(1000,1000,1000);
+  style.primarySelectionColor = Color(1000,0,0);
+  style.secondarySelectionColor = Color(1000,0,1000);
   style.classicGrid = false;
   style.thinLine = 0.2;
   style.thickLine = 0.9;
@@ -810,6 +827,16 @@ static int appui_constructor(lua_State *L)
       style.paperColor = check_color(L, lua_gettop(L));
     lua_pop(L, 1); // paper_color
 
+    lua_getfield(L, -1, "primary_color");
+    if (!lua_isnil(L, -1))
+      style.primarySelectionColor = check_color(L, lua_gettop(L));
+    lua_pop(L, 1); // primary_color
+
+    lua_getfield(L, -1, "secondary_color");
+    if (!lua_isnil(L, -1))
+      style.secondarySelectionColor = check_color(L, lua_gettop(L));
+    lua_pop(L, 1); // secondary_color
+
     lua_getfield(L, -1, "classic_grid");
     style.classicGrid = lua_toboolean(L, -1);
     lua_pop(L, 1); // classic_grid
