@@ -153,14 +153,14 @@ cairo_font_face_t *Fonts::screenFont()
 /*! Corresponds to a Freetype "face", or a PDF font resource.  A Face
   can be loaded at various sizes (transformations), resulting in
   individual FaceSize's. */
-Face *Fonts::getFace(int id)
+Face *Fonts::getFace(const PdfDict *d)
 {
   auto it = std::find_if(iFaces.begin(), iFaces.end(),
-			 [id](const Face *f) { return f->matches(id); } );
+			 [d](const Face *f) { return f->matches(d); } );
   if (it != iFaces.end())
     return *it;
 
-  Face *face = new Face(id, iResources);
+  Face *face = new Face(d, iResources);
   iFaces.push_back(face);
   return face;
 }
@@ -179,20 +179,16 @@ static void face_data_destroy(FaceData *face_data)
   delete face_data;  // discard memory buffer
 }
 
-static const cairo_user_data_key_t key = { 0 };
+static const cairo_user_data_key_t datakey = { 0 };
 
 /*! \class ipe::Face
   \ingroup cairo
   \brief A typeface (aka font), actually loaded (from a font file or PDF file).
 */
 
-Face::Face(int id, const PdfResources *resources) noexcept
-:  iId(id), iResources(resources)
+Face::Face(const PdfDict *d, const PdfResources *resources) noexcept
+:  iFontDict(d), iResources(resources)
 {
-  ipeDebug("Loading face for id %d", id);
-  const PdfDict *d = iResources->getFont(id);
-  if (!d)
-    return;
   /* d:
     /Type /Font
     /Subtype /Type1
@@ -228,7 +224,7 @@ Face::Face(int id, const PdfResources *resources) noexcept
       return;
     t = type->name()->value();
   }
-  const PdfObj *name = d->get("BaseFont", nullptr);
+  const PdfObj *name = getPdf(d, "BaseFont");
   if (!name || !name->name())
     return;
   iName = name->name()->value();
@@ -236,7 +232,7 @@ Face::Face(int id, const PdfResources *resources) noexcept
 
   if (t == "Type1")
     iType = FontType::Type1;
-  else if (t == "Truetype")
+  else if (t == "TrueType")
     iType = FontType::Truetype;
   else if (t == "CIDFontType0")
     iType = FontType::CIDType0;
@@ -248,8 +244,10 @@ Face::Face(int id, const PdfResources *resources) noexcept
   }
 
   Buffer data;
-  if (!getFontFile(d, data))
+  if (!getFontFile(d, data)) {
+    ipeDebug("Failed to get font file for %s", iName.z());
     return;
+  }
 
   if (FT_New_Memory_Face(engine.iLib, (const uchar *) data.data(),
 			 data.size(), 0, &iFace))
@@ -263,7 +261,7 @@ Face::Face(int id, const PdfResources *resources) noexcept
   // it explains why the user_data is necessary
   iCairoFont = cairo_ft_font_face_create_for_ft_face(iFace, 0);
   cairo_status_t status =
-    cairo_font_face_set_user_data(iCairoFont, &key, face_data,
+    cairo_font_face_set_user_data(iCairoFont, &datakey, face_data,
 				  (cairo_destroy_func_t) face_data_destroy);
   if (status) {
     ipeDebug("Failed to set user data for Cairo font");
@@ -298,7 +296,7 @@ Face::Face(int id, const PdfResources *resources) noexcept
 Face::~Face() noexcept
 {
   if (iCairoFont) {
-    ipeDebug("Done with Cairo face %d (%d references left)", iId,
+    ipeDebug("Done with Cairo face %s (%d references left)", iName.z(),
 	     cairo_font_face_get_reference_count(iCairoFont));
     ++engine.iFacesUnloaded;
     cairo_font_face_destroy(iCairoFont);
@@ -307,12 +305,7 @@ Face::~Face() noexcept
 
 const PdfObj *Face::getPdf(const PdfDict *d, String key) const noexcept
 {
-  const PdfObj *obj = d->get(key, nullptr);
-  if (!obj)
-    return obj;
-  if (obj->ref())
-    return iResources->object(obj->ref()->value());
-  return obj;
+  return iResources->getDeep(d, key);
 }
 
 // --------------------------------------------------------------------
@@ -410,6 +403,7 @@ void Face::getSimpleWidth(const PdfDict *d) noexcept
     const PdfObj *obj = wid->array()->obj(i, nullptr);
     iWidth.push_back(obj->number() ? int(obj->number()->value()) : 0);
   }
+  ipeDebug("Got %d widths entries", iWidth.size());
 }
 
 // --------------------------------------------------------------------
@@ -439,6 +433,7 @@ void Face::getType1Encoding(const PdfDict *d) noexcept
       int glyph = FT_Get_Name_Index(iFace, const_cast<char *>(name[i].z()));
       iEncoding.push_back(glyph);
     }
+    ipeDebug("Got %d encoding entries", iEncoding.size());
   } else {
     // font has no encoding
     for (int k = 0; k < iFace->num_charmaps; ++k) {
@@ -458,8 +453,8 @@ void Face::setupTruetypeEncoding() noexcept
   FT_Set_Charmap(iFace, iFace->charmaps[0]);
   if (iFace->charmaps[0]->platform_id != 1 ||
       iFace->charmaps[0]->encoding_id != 0) {
-    ipeDebug("TrueType face %d has strange first charmap (of %d)",
-	     iId, iFace->num_charmaps);
+    ipeDebug("TrueType face %s has strange first charmap (of %d)",
+	     iName.z(), iFace->num_charmaps);
     for (int i = 0; i < iFace->num_charmaps; ++i) {
       ipeDebug("Map %d has platform %d, encoding %d",
 	       i, iFace->charmaps[i]->platform_id,
