@@ -85,6 +85,7 @@ CanvasBase::CanvasBase()
   iFifiMode = Snap::ESnapNone;
   iSelectionVisible = true;
 
+  isInkMode = false;
   iAdditionalModifiers = 0;
 
   iStyle.paperColor = Color(1000,1000,1000);
@@ -600,7 +601,7 @@ void CanvasBase::setSelectionVisible(bool visible)
 Vector CanvasBase::simpleSnapPos() const
 {
   Vector pos = iUnsnappedMousePos;
-  iSnap.simpleSnap(pos, iPage, iSnap.iSnapDistance / iZoom);
+  iSnap.simpleSnap(pos, iPage, iView, iSnap.iSnapDistance / iZoom);
   return pos;
 }
 
@@ -633,7 +634,8 @@ void CanvasBase::computeFifi(double x, double y)
 
   int mask = iAutoSnap ? 0 : Snap::ESnapAuto;
   if (iSnap.iSnap & ~mask) {
-    iFifiMode = iSnap.snap(iMousePos, iPage, iSnap.iSnapDistance / iZoom,
+    iFifiMode = iSnap.snap(iMousePos, iPage, iView,
+			   iSnap.iSnapDistance / iZoom,
 			   iTool, (iAutoSnap ? &iAutoOrigin : 0));
     if (iFifiMode == Snap::ESnapNone)
       snapToPaperAndFrame();
@@ -666,7 +668,7 @@ void CanvasBase::refreshSurface()
 	     iWidth, iHeight, iBWidth, iBHeight);
     if (iSurface)
       cairo_surface_destroy(iSurface);
-    iSurface = 0;
+    iSurface = nullptr;
     iRepaintObjects = true;
     // give Ipe a chance to set pan and zoom according to new size
     if (iObserver)
