@@ -111,6 +111,9 @@ namespace ipe {
     //! Return current snapping information.
     inline const Snap &snap() const { return iSnap; }
 
+    //! Set ink mode.
+    inline void setInkMode(bool ink) { isInkMode = ink; }
+
     //! Return current additional modifiers.
     inline int additionalModifiers() const { return iAdditionalModifiers; }
     void setAdditionalModifiers(int mod);
@@ -187,6 +190,7 @@ namespace ipe {
     bool iAutoSnap;
     Vector iAutoOrigin;
     int iAdditionalModifiers;
+    bool isInkMode;
 
     bool iRepaintObjects;
     double iWidth, iHeight;
