@@ -42,6 +42,7 @@ namespace ipe {
   class Canvas : public CanvasBase {
   public:
     static void init(HINSTANCE hInstance);
+    static UINT getDpiForWindow(HWND hwnd);
     Canvas(HWND parent);
 
     HWND windowId() const { return hwnd; }
@@ -77,6 +78,7 @@ namespace ipe {
     int iGestureDist;
     Vector iGesturePan;
     double iGestureZoom;
+    UINT32 iPointerId;
     Vector iHimetric;
     bool isTransient;
   };
