@@ -282,7 +282,7 @@ bool SelectTool::key(String text, int modifiers)
   \ingroup canvas
   \brief A tool for transforming the selected objects on the canvas.
 
-  Supports moving, rotating, scaling, and stretching.
+  Supports moving, rotating, scaling, stretching, and shearing.
 */
 
 //! Constructor starts transformation.
@@ -314,7 +314,7 @@ TransformTool::TransformTool(CanvasBase *canvas, Page *page, int view,
       pin = TPinned(pin | page->object(i)->pinned());
   }
 
-  // rotating, scaling, and stretching are not allowed on pinned objects
+  // rotating, scaling, stretching, shearing are not allowed on pinned objects
   if (pin == EFixedPin || (pin && iType != ETranslate)) {
     iValid = false;
     return;
@@ -332,7 +332,9 @@ TransformTool::TransformTool(CanvasBase *canvas, Page *page, int view,
   const Snap &sd = iCanvas->snap();
   if (sd.iWithAxes) {
     iOrigin = sd.iOrigin;
+    iDir = sd.iDir;
   } else {
+    iDir = 0.0;
     // find bounding box of selected objects
     Rect bbox;
     for (int i = 0; i < iPage->count(); ++i) {
@@ -340,7 +342,7 @@ TransformTool::TransformTool(CanvasBase *canvas, Page *page, int view,
 	bbox.addRect(iPage->bbox(i));
     }
     iOrigin = 0.5 * (bbox.bottomLeft() + bbox.topRight());
-    if (iType == EStretch || iType == EScale) {
+    if (iType == EStretch || iType == EScale || iType == EShear) {
       if (iMouseDown.x > iOrigin.x)
 	iOrigin.x = bbox.bottomLeft().x;
       else
@@ -352,7 +354,9 @@ TransformTool::TransformTool(CanvasBase *canvas, Page *page, int view,
     }
   }
 
-  if (iType != ETranslate && iMouseDown == iOrigin)
+  if (iType == EShear && abs((Linear(-iDir) * (iMouseDown - iOrigin)).y) < 0.1)
+    iValid = false;
+  else if (iType != ETranslate && iMouseDown == iOrigin)
     iValid = false;
   else
     iCanvas->setCursor(CanvasBase::EHandCursor);
@@ -407,6 +411,15 @@ void TransformTool::compute(const Vector &v1)
 		  Linear(xfactor, 0, 0, yfactor) *
 		  Matrix(-iOrigin));
     break; }
+  case EShear: {
+    auto rot = Linear(-iDir);
+    auto v0 = rot * u0;
+    auto v1 = rot * u1;
+    double s = (v1.x - v0.x) / v0.y;
+    iTransform = (Matrix(iOrigin) * Linear(iDir) *
+		  Linear(1.0, 0, s, 1.0) * rot *
+		  Matrix(-iOrigin));
+    break; }
   }
 }
 
