@@ -4,7 +4,7 @@
 --[[
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -109,6 +109,11 @@ function preciseTransform(model, num)
     if not str or str:match("^%s*$") then return end
     if str:match("^[%+%-%d%.]+$") then
       local sx = tonumber(str)
+      if sx == 0 then
+	model:warning("Illegal scale factor",
+		      "You cannot use a zero scale factor")
+	return
+      end
       label = "scale by " .. sx
       matrix = ipe.Matrix(sx, 0, 0, sx, 0, 0)
     else
@@ -120,6 +125,11 @@ function preciseTransform(model, num)
 	return
       end
       local sx, sy = tonumber(ssx), tonumber(ssy)
+      if sx == 0 or sy == 0 then
+	model:warning("Illegal stretch factor",
+		      "You cannot use a zero stretch factor")
+	return
+      end
       label = "stretch by " .. sx .. ", " .. sy
       matrix = ipe.Matrix(sx, 0, 0, sy, 0, 0)
     end
