@@ -53,7 +53,7 @@
 namespace ipe {
   const char *const kind_names[] = {
     "pen", "symbolsize", "arrowsize", "color",
-    "dashstyle", "textsize", "textstretch", "textstyle",
+    "dashstyle", "textsize", "textstretch", "textstyle", "labelstyle",
     "gridsize", "anglesize", "opacity", "tiling",
     "symbol", "gradient", "effect", 0 };
 
@@ -64,12 +64,12 @@ namespace ipe {
     "farrowshape", "rarrowshape",
     "stroke", "fill", "markshape",
     "pathmode", "dashstyle",
-    "textsize", "textstyle",
+    "textsize", "textstyle", "labelstyle",
     "opacity", "tiling", "gradient",
     "horizontalalignment", "verticalalignment",
     "linejoin", "linecap", "fillrule",
     "pinned", "transformations", "transformabletext",
-    "minipage", "width", 0 };
+    "minipage", "width", "decoration", 0 };
 }
 
 using namespace ipe;
@@ -472,7 +472,7 @@ AllAttributes::AllAttributes()
   iPen = iFArrowSize = iRArrowSize = Attribute::NORMAL();
   iFArrowShape = iRArrowShape = Attribute::ARROW_NORMAL();
   iFArrow = iRArrow = false;
-  iSymbolSize = iTextSize = iTextStyle = Attribute::NORMAL();
+  iSymbolSize = iTextSize = iTextStyle = iLabelStyle = Attribute::NORMAL();
   iTransformableText = false;
   iVerticalAlignment = EAlignBaseline;
   iHorizontalAlignment = EAlignLeft;
