@@ -199,7 +199,8 @@ void String::detach(int n) noexcept
     iImp = new Imp;
     iImp->iRefCount = 1;
     iImp->iSize = 0;
-    iImp->iCapacity = 16;
+    n = (n + 0x1f) & ~0x1f;
+    iImp->iCapacity = (n >= 16) ? n : 16;
     iImp->iData = new char[iImp->iCapacity];
   } else if (iImp->iRefCount > 1 || (iImp->iSize + n > iImp->iCapacity)) {
     Imp *imp = new Imp;
