@@ -337,7 +337,7 @@ void Bitmap::computeChecksum()
 
 //! Convert bitmap data to a height x width pixel array in rgb format.
 /*! Returns empty buffer if it cannot decode the bitmap information.
-  Otherwise, returns a buffer of size width() * height() uint's. */
+  Otherwise, returns a buffer of size width() * height() uint32_t's. */
 Buffer Bitmap::pixelData() const
 {
   ipeDebug("pixelData %d x %d x %d, %d", width(), height(),
@@ -361,10 +361,10 @@ Buffer Bitmap::pixelData() const
     if (!dctDecode(stream, pixels, components()))
       return Buffer();
   }
-  Buffer data(height() * width() * sizeof(uint));
+  Buffer data(height() * width() * sizeof(uint32_t));
   // convert pixels to data
   const char *p = pixels.data();
-  uint *q = (uint *) data.data();
+  uint32_t *q = (uint *) data.data();
   if (components() == 3) {
     uint colorKey = (iImp->iColorKey | 0xff000000);
     if (iImp->iColorKey < 0)
@@ -374,7 +374,7 @@ Buffer Bitmap::pixelData() const
 	uchar r = uchar(*p++);
 	uchar g = uchar(*p++);
 	uchar b = uchar(*p++);
-	uint pixel = 0xff000000 | (r << 16) | (g << 8) | b;
+	uint32_t pixel = 0xff000000 | (r << 16) | (g << 8) | b;
 	if (pixel == colorKey)
 	  *q++ = 0;
 	else
