@@ -3,7 +3,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #include <png.h>
 
 #ifdef __APPLE__
-#include <CoreGraphics.h>
+#include <CoreGraphics/CoreGraphics.h>
 #else
 #include <csetjmp>
 #include <jpeglib.h>
@@ -59,8 +59,11 @@ bool dctDecode(Buffer dctData, Buffer pixelData, int components)
 
   int w = CGImageGetWidth(bitmap);
   int h = CGImageGetHeight(bitmap);
-  int bytes = CGImageGetBitsPerPixel(bitmap) / 8;
+  int bits = CGImageGetBitsPerPixel(bitmap);
   int stride = CGImageGetBytesPerRow(bitmap);
+  if (bits != 8 && bits != 24 && bits != 32)
+    return false;
+  int bytes = bits / 8;
 
   CGBitmapInfo info = CGImageGetBitmapInfo(bitmap);
   // TODO: check for alpha channel, float pixel values, and byte order?
@@ -72,15 +75,24 @@ bool dctDecode(Buffer dctData, Buffer pixelData, int components)
   const uchar *inRow = CFDataGetBytePtr(pixels);
 
   uchar *q = (uchar *) pixelData.data();
-  for (int y = 0; y < h; ++y) {
-    const uchar *p = inRow;
-    for (int x = 0; x < w; ++x) {
-      *q++ = p[0];
-      *q++ = p[1];
-      *q++ = p[2];
-      p += bytes;
+  if (bits !=  8) {
+    for (int y = 0; y < h; ++y) {
+      const uchar *p = inRow;
+      for (int x = 0; x < w; ++x) {
+	*q++ = p[0];
+	*q++ = p[1];
+	*q++ = p[2];
+	p += bytes;
+      }
+      inRow += stride;
+    }
+  } else {
+    for (int y = 0; y < h; ++y) {
+      const uchar *p = inRow;
+      for (int x = 0; x < w; ++x)
+	*q++ = *p++;
+      inRow += stride;
     }
-    inRow += stride;
   }
   CFRelease(pixels);
   CGImageRelease(bitmap);
