@@ -533,22 +533,7 @@ void Document::findBitmaps(BitmapFinder &bm) const
 //! Save in XML format into an Stream.
 void Document::saveAsXml(Stream &stream, bool usePdfBitmaps) const
 {
-  // check file format update to 7.2.4
-  int ff = ipe::FILE_FORMAT;
-  for (int i = 0; i < countPages(); ++i) {
-    const Page *p = page(i);
-    for (int j = 0; j < p->count(); ++j) {
-      const Group *g = p->object(j)->asGroup();
-      if (g && !g->url().empty()) {
-	ff = ipe::FILE_FORMAT_NEW;
-      }
-    }
-  }
-  for (int i = 0; i < iCascade->count() - 1; ++i) { // skip standard stylesheet
-    if (iCascade->sheet(i)->pageNumberStyle())
-      ff = ipe::FILE_FORMAT_NEW;
-  }
-  stream << "<ipe version=\"" << ff << "\"";
+  stream << "<ipe version=\"" << FILE_FORMAT << "\"";
   if (!iProperties.iCreator.empty())
     stream << " creator=\"" << iProperties.iCreator << "\"";
   stream << ">\n";
@@ -824,6 +809,7 @@ int Document::runLatex(String &texLog)
 
   if (okay) {
     setResources(converter.takeResources());
+    resources()->show();
     return ErrNone;
   } else
     return ErrLatexOutput;
