@@ -435,6 +435,9 @@ bool ImlParser::parseStyle(StyleSheet &sheet)
   if (att.has("name", name))
     sheet.setName(name);
 
+  if (att.slash())
+    return true;
+
   String tag = parseToTag();
   while (tag != "/ipestyle") {
     if (tag == "bitmap") {
@@ -680,6 +683,9 @@ bool ImlParser::parseStyle(StyleSheet &sheet)
 					      Attribute::NORMAL());
       if (name.empty() || value.isSymbolic())
 	return false;
+      if (kind == EGridSize &&
+	  (!value.isNumber() || !value.number().isInteger()))
+	return false; // refuse non-integer gridsize
       sheet.add(kind, Attribute(true, name), value);
     }
     tag = parseToTag();
