@@ -191,6 +191,10 @@ int Latex::createLatexSource(Stream &stream, String preamble)
       stream << "\\ifnum\\the\\pdftexversion<140"
 	     << "\\errmessage{Pdftex is too old. "
 	     << "Set IPEANCIENTPDFTEX environment variable!}\\fi\n";
+    if (iLatexType == LatexType::Luatex)
+      // load luatex85 for new versions of Luatex
+      stream << "\\expandafter\\ifx\\csname pdfcolorstack\\endcsname\\relax"
+	     << "\\RequirePackage{luatex85}\\fi\n";
   }
   stream << "\\documentclass{article}\n"
 	 << "\\usepackage{xcolor}\n"
