@@ -327,7 +327,7 @@ bool Object::setAttribute(Property prop, Attribute value)
 //! Get setting of an attribute of this object.
 /*! If object does not have this attribute, returnes "undefined"
   attribute. */
-Attribute Object::getAttribute(Property prop)
+Attribute Object::getAttribute(Property prop) const noexcept
 {
   switch (prop) {
   case EPropPinned:
