@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -424,6 +424,14 @@ void Painter::setSymPen(Attribute pen)
     iState.back().iSymPen = iCascade->find(EPen, pen).number();
 }
 
+//! Set full graphics state at once.
+void Painter::setState(const State &state)
+{
+  iState.back() = state;
+}
+
+// --------------------------------------------------------------------
+
 // Coordinate for bezier approximation for quarter circle.
 const double BETA = 0.55228474983079334;
 const double PI15 = IpePi + IpeHalfPi;
