@@ -172,16 +172,12 @@ void Path::init(const AllAttributes &attr, bool withArrows)
   iFArrowShape = iRArrowShape = Attribute::ARROW_NORMAL();
   iFArrowSize = iRArrowSize = Attribute::NORMAL();
   if (withArrows) {
-    if (attr.iFArrow) {
-      iHasFArrow = true;
-      iFArrowShape = attr.iFArrowShape;
-      iFArrowSize = attr.iFArrowSize;
-    }
-    if (attr.iRArrow) {
-      iHasRArrow = true;
-      iRArrowShape = attr.iRArrowShape;
-      iRArrowSize = attr.iRArrowSize;
-    }
+    iFArrowShape = attr.iFArrowShape;
+    iRArrowShape = attr.iRArrowShape;
+    iFArrowSize = attr.iFArrowSize;
+    iRArrowSize = attr.iRArrowSize;
+    iHasFArrow = attr.iFArrow;
+    iHasRArrow = attr.iRArrow;
   }
 }
 
@@ -533,7 +529,6 @@ void Path::setOpacity(Attribute opaq)
 //! Set pen.
 void Path::setPen(Attribute pen)
 {
-  ipeDebug("set pen");
   iPen = pen;
 }
 
@@ -708,7 +703,7 @@ bool Path::setAttribute(Property prop, Attribute value)
   return false;
 }
 
-Attribute Path::getAttribute(Property prop)
+Attribute Path::getAttribute(Property prop) const noexcept
 {
   switch (prop) {
   case EPropPathMode:
