@@ -117,7 +117,7 @@ String PdfObj::repr() const noexcept
  */
 const PdfNull *PdfNull::null() const noexcept { return this; }
 
-void PdfNull::write(Stream &stream, const PdfRenumber *) const noexcept
+void PdfNull::write(Stream &stream, const PdfRenumber *, bool infl) const noexcept
 {
   stream << "null";
 }
@@ -128,7 +128,7 @@ void PdfNull::write(Stream &stream, const PdfRenumber *) const noexcept
  */
 const PdfBool *PdfBool::boolean() const noexcept { return this; }
 
-void PdfBool::write(Stream &stream, const PdfRenumber *) const noexcept
+void PdfBool::write(Stream &stream, const PdfRenumber *, bool infl) const noexcept
 {
   stream << (iValue ? "true" : "false");
 }
@@ -139,7 +139,7 @@ void PdfBool::write(Stream &stream, const PdfRenumber *) const noexcept
  */
 const PdfNumber *PdfNumber::number() const noexcept { return this; }
 
-void PdfNumber::write(Stream &stream, const PdfRenumber *) const noexcept
+void PdfNumber::write(Stream &stream, const PdfRenumber *, bool infl) const noexcept
 {
   stream << iValue;
 }
@@ -150,7 +150,8 @@ void PdfNumber::write(Stream &stream, const PdfRenumber *) const noexcept
  */
 const PdfString *PdfString::string() const noexcept { return this; }
 
-void PdfString::write(Stream &stream, const PdfRenumber *) const noexcept
+void PdfString::write(Stream &stream, const PdfRenumber *, bool infl)
+  const noexcept
 {
   if (iBinary) {
     stream << "<" << iValue << ">";
@@ -187,7 +188,7 @@ String PdfString::decode() const noexcept
  */
 const PdfName *PdfName::name() const noexcept { return this; }
 
-void PdfName::write(Stream &stream, const PdfRenumber *) const noexcept
+void PdfName::write(Stream &stream, const PdfRenumber *, bool infl) const noexcept
 {
   stream << "/" << iValue;
 }
@@ -198,7 +199,8 @@ void PdfName::write(Stream &stream, const PdfRenumber *) const noexcept
  */
 const PdfRef *PdfRef::ref() const noexcept { return this; }
 
-void PdfRef::write(Stream &stream, const PdfRenumber *renumber) const noexcept
+void PdfRef::write(Stream &stream, const PdfRenumber *renumber,
+		   bool infl) const noexcept
 {
   if (renumber) {
     auto it = renumber->find(iValue);
@@ -216,7 +218,8 @@ void PdfRef::write(Stream &stream, const PdfRenumber *renumber) const noexcept
  */
 const PdfArray *PdfArray::array() const noexcept { return this; }
 
-void PdfArray::write(Stream &stream, const PdfRenumber *renumber) const noexcept
+void PdfArray::write(Stream &stream, const PdfRenumber *renumber,
+		     bool infl) const noexcept
 {
   stream << "[";
   String sep = "";
@@ -268,21 +271,45 @@ const PdfObj *PdfArray::obj(int index, const PdfFile *file) const noexcept
 
 const PdfDict *PdfDict::dict() const noexcept { return this; }
 
-void PdfDict::write(Stream &stream, const PdfRenumber *renumber) const noexcept
+//! Return PDF representation of the PdfDict without the stream.
+String PdfDict::dictRepr() const noexcept
 {
-  String sep = "<<";
+  String d;
+  StringStream ss(d);
+  dictWrite(ss, nullptr, false, iStream.size());
+  return d;
+}
+
+void PdfDict::dictWrite(Stream &stream,
+			const PdfRenumber *renumber,
+			bool infl, int length) const noexcept
+{
+  stream << "<<";
   for (std::vector<Item>::const_iterator it = iItems.begin();
        it != iItems.end(); ++it) {
-    stream << sep;
-    sep = " ";
+    if (it != iItems.begin())
+      stream << " ";
+    if (infl && it->iKey == "Filter" && it->iVal->name()
+	&& it->iVal->name()->value() == "FlateDecode")
+      continue;   // remove filter and inflate stream
     stream << "/" << it->iKey << " ";
-    it->iVal->write(stream, renumber);
+    if (it->iKey == "Length")
+      stream << length;
+    else
+      it->iVal->write(stream, renumber);
   }
   stream << ">>";
-  if (iStream.size() > 0) {
+}
+
+void PdfDict::write(Stream &stream, const PdfRenumber *renumber,
+		    bool infl) const noexcept
+{
+  Buffer s = infl ? inflate() : iStream;
+  dictWrite(stream, renumber, infl, s.size());
+  if (s.size() > 0) {
     stream << "\nstream\n";
-    for (int i = 0; i < iStream.size(); ++i)
-      stream.putChar(iStream[i]);
+    for (int i = 0; i < s.size(); ++i)
+      stream.putChar(s[i]);
     stream << "\nendstream";
   }
 }
@@ -601,6 +628,10 @@ PdfDict *PdfParser::makeDict()
       getChar(); // skip '\n'
       // now at beginning of stream
       const PdfObj *len = dict->get("Length", 0);
+      if (len && len->ref()) {
+	ipeDebug("/Length entry of dictionary is a reference.");
+	return nullptr;
+      }
       if (!len || !len->number())
 	return nullptr;
       int bytes = int(len->number()->value());
