@@ -209,76 +209,13 @@ void PdfPainter::doDrawText(const Text *text)
   const Text::XForm *xf = text->getXForm();
   if (!xf)
     return;
-
-  Color s = stroke();
   drawOpacity();
-
+  pushMatrix();
+  transform(Matrix(xf->iStretch, 0, 0, xf->iStretch, 0, 0));
+  translate(xf->iTranslation);
   iStream << matrix() << " cm " ;
-  if (xf->iStretch != 1.0 || xf->iBBox.bottomLeft() != Vector::ZERO)
-    iStream << Matrix(xf->iStretch, 0, 0, xf->iStretch,
-		      -xf->iBBox.bottomLeft().x,
-		      -xf->iBBox.bottomLeft().y) << " cm ";
-
-  BufferSource source(xf->iStream);
-  PdfParser parser(source);
-  std::vector<const PdfObj *> args;
-  while (!parser.eos()) {
-    PdfToken tok = parser.token();
-    if (tok.iType != PdfToken::EOp) {
-      const PdfObj *obj = parser.getObject();
-      if (!obj) {
-	ipeDebug("Error parsing PDF text");
-	break; // no further parsing attempted
-      }
-      args.push_back(obj);
-    } else {
-      // its an operator, execute it
-      String op = tok.iString;
-      parser.getToken();
-      if (op == "k") {
-	drawColor(iStream, s, "g", "rg");
-      } else if (op == "K") {
-	drawColor(iStream, s, "G", "RG");
-      } else if (op == "sym") {
-	if (args.size() == 5) {
-	  String s[5];
-	  for (int i = 0; i < 5; ++i) {
-	    if (args[i]->string())
-	      s[i] = args[i]->string()->value();
-	  }
-	  // ipeDebug("render Symbol %s, %s, %s, %s, %s",
-	  // s[0].z(), s[1].z(), s[2].z(), s[3].z(), s[4].z());
-	  const Symbol *symbol =
-	    cascade()->findSymbol(Attribute(true, s[0]));
-	  if (symbol) {
-	    PdfPainter sympt(cascade(), iStream);
-	    sympt.pushMatrix();
-	    double sa = Lex(s[1]).getDouble();
-	    Matrix m(sa, 0, 0, sa, 0, 0);
-	    sympt.transform(m);
-	    sympt.setSymStroke(Attribute::makeColor(s[2], Attribute::BLACK()));
-	    sympt.setSymFill(Attribute::makeColor(s[3], Attribute::WHITE()));
-	    sympt.setSymPen(Attribute::makeScalar(s[4], Attribute::NORMAL()));
-	    symbol->iObject->draw(sympt);
-	    sympt.popMatrix();
-	  }
-	}
-      } else {
-	for (uint i = 0; i < args.size(); ++i)
-	  iStream << args[i]->repr() << " ";
-	iStream << op << "\n";
-      }
-      while (!args.empty()) {
-	delete args.back();
-	args.pop_back();
-      }
-    }
-  }
-  // delete remaining args
-  while (!args.empty()) {
-    delete args.back();
-    args.pop_back();
-  }
+  iStream << "/" << xf->iName << " Do\n";
+  popMatrix();
 }
 
 void PdfPainter::doDrawSymbol(Attribute symbol)
@@ -310,7 +247,10 @@ void PdfPainter::doDrawSymbol(Attribute symbol)
     - 0: Must be left empty (a PDF restriction).
     - 1:  XML stream.
     - 2: Parent of all pages objects.
-
+    - 3: ExtGState resource from pdflatex
+    - 4: Shading resource from pdflatex
+    - 5: Pattern resource from pdflatex
+    - 6: ColorSpace resource from pdflatex
 */
 
 //! Create a PDF writer operating on this (open and empty) file.
@@ -322,9 +262,8 @@ PdfWriter::PdfWriter(TellStream &stream, const Document *doc,
     iFromPage(fromPage), iToPage(toPage)
 {
   iCompressLevel = compression;
-  iObjNum = 3;  // 0 - 2 are reserved
+  iObjNum = 7;  // 0 - 6 are reserved
   iXmlStreamNum = -1; // no XML stream yet
-  iResourceNum = -1;
   iExtGState = -1;
   iPatternNum = -1;
   iBookmarks = -1;
@@ -346,10 +285,19 @@ PdfWriter::PdfWriter(TellStream &stream, const Document *doc,
 
   iStream << "%PDF-1.4\n";
 
-  // embed all opacities
+  // embed all fonts and other resources from Pdflatex
+  embedResources();
+
+  // embed resources from pdflatex
+  embedLatexResource(3, "ExtGState");
+  embedLatexResource(4, "Shading");
+  embedLatexResource(5, "Pattern");
+  embedLatexResource(6, "ColorSpace");
+
+  // embed all extgstate objects
   AttributeSeq os;
   iDoc->cascade()->allNames(EOpacity, os);
-  if (os.size()) {
+  if (os.size() > 0) {
     iExtGState = startObject();
     iStream << "<<\n";
     for (uint i = 0; i < os.size(); ++i) {
@@ -452,9 +400,6 @@ PdfWriter::PdfWriter(TellStream &stream, const Document *doc,
     iStream << ">> endobj\n";
   }
 
-  // embed all fonts and other resources from Pdflatex
-  embedResources(resources);
-
   // embed all symbols with xform attribute
   AttributeSeq sys;
   iDoc->cascade()->allNames(ESymbol, sys);
@@ -505,26 +450,127 @@ int PdfWriter::startObject(int objnum)
   return objnum;
 }
 
+bool PdfWriter::hasResource(String kind) const noexcept
+{
+  return iResources && iResources->resourcesOfKind(kind);
+}
+
 /*! Write all PDF resources to the PDF file, and record their object
   numbers.  Embeds nothing if \c resources is nullptr, but must be
   called nevertheless. */
-void PdfWriter::embedResources(const PdfResources *resources)
+void PdfWriter::embedResources()
 {
-  std::unordered_map<int, int> resourceNumber;
-
-  if (resources) {
-    const std::vector<int> &seq = resources->embedSequence();
+  bool inflate = (iCompressLevel == 0);
+  if (iResources) {
+    const std::vector<int> &seq = iResources->embedSequence();
     for (auto &num : seq) {
-      const PdfObj *obj = resources->object(num);
+      const PdfObj *obj = iResources->object(num);
       int embedNum = startObject();
-      obj->write(iStream, &resourceNumber);
+      if (obj->dict() && obj->dict()->get("IpeId", nullptr))
+	embedIpeXForm(obj->dict());
+      else
+	obj->write(iStream, &iResourceNumber, inflate);
       iStream << " endobj\n";
-      resourceNumber[num] = embedNum;
+      iResourceNumber[num] = embedNum;
     }
-    iResourceNum = startObject();
-    const PdfDict *font = resources->get("Font");
-    font->write(iStream,  &resourceNumber);
-    iStream << " endobj\n";
+  }
+}
+
+void PdfWriter::embedIpeXForm(const PdfDict *d)
+{
+  bool inflate = (iCompressLevel == 0) && d->deflated();
+  iStream << "<<";
+  for (int i = 0; i < d->count(); ++i) {
+    String key = d->key(i);
+    // skip /IpeId etc keys
+    if (key.left(3) == "Ipe") {
+      ipeDebug("Skipping key %s", key.z());
+      continue;
+    }
+    if ((inflate && key == "Filter") || key == "Length")
+      continue;   // remove /FlateDecode filter and /Length
+    iStream << "/" << key << " ";
+    if (key == "Resources") {
+      const PdfObj *res = d->value(i);
+      if (res->ref())
+	res = iResources->object(res->ref()->value());
+      if (res->dict())
+	embedXFormResource(res->dict());
+      else	// should not happen!
+	d->value(i)->write(iStream, &iResourceNumber);
+    } else if (key == "BBox") {
+      const TextPadding *pad = iDoc->cascade()->findTextPadding();
+      std::vector<double> bbox;
+      d->getNumberArray("BBox", nullptr, bbox);
+      if (pad && bbox.size() == 4) {
+	bbox[0] -= pad->iLeft;
+	bbox[1] -= pad->iBottom;
+	bbox[2] += pad->iRight;
+	bbox[3] += pad->iTop;
+      }
+      iStream << "[";
+      for (auto it = bbox.begin(); it != bbox.end(); ++it)
+	iStream << *it << " ";
+      iStream << "]";
+    } else
+      d->value(i)->write(iStream, &iResourceNumber);
+    iStream << " ";
+  }
+  Buffer stream = inflate ? d->inflate() : d->stream();
+  if (stream.size() > 0) {
+    iStream << "/Length " << stream.size()
+	    << ">>\nstream\n";
+    for (int i = 0; i < stream.size(); ++i)
+      iStream.putChar(stream[i]);
+    iStream << "\nendstream";
+  } else
+    iStream << ">>";
+}
+
+void PdfWriter::embedXFormResource(const PdfDict *d)
+{
+  iStream << "<<";
+  for (int i = 0; i < d->count(); ++i) {
+    String key = d->key(i);
+    iStream << "/" << key << " ";
+    if (key == "ColorSpace" || key == "Shading" || key == "Pattern" ||
+	key == "ExtGState") {
+      ipeDebug("PDF Writer: Conflicting resource in XForm: %s", key.z());
+    } else
+      d->value(i)->write(iStream, &iResourceNumber);
+  }
+  if (hasResource("ExtGState"))
+    iStream << "/ExtGState 3 0 R\n";
+  if (hasResource("Shading"))
+    iStream << "/ColorSpace 4 0 R\n";
+  if (hasResource("Pattern"))
+    iStream << "/Pattern 5 0 R\n";
+  if (hasResource("ColorSpace"))
+    iStream << "/ColorSpace 6 0 R\n";
+  iStream << ">>";
+}
+
+void PdfWriter::embedLatexResource(int num, String kind)
+{
+  if (hasResource(kind)) {
+    startObject(num);
+    iStream << "<<\n";
+    embedResource(kind);
+    iStream << ">> endobj\n";
+  }
+}
+
+void PdfWriter::embedResource(String kind)
+{
+  if (!iResources)
+    return;
+  const PdfDict *d = iResources->resourcesOfKind(kind);
+  if (!d)
+    return;
+  for (int i = 0; i < d->count(); ++i) {
+    iStream << "/" << d->key(i) << " ";
+    d->value(i)->write(iStream, &iResourceNumber);
+    iStream << " ";
   }
 }
 
@@ -546,7 +592,7 @@ void PdfWriter::createStream(const char *data, int size, bool preCompressed)
   if (iCompressLevel > 0) {
     int deflatedSize;
     Buffer deflated = DeflateStream::deflate(data, size, deflatedSize,
-						   iCompressLevel);
+					     iCompressLevel);
     iStream << "/Length " << deflatedSize
 	    << " /Filter /FlateDecode >>\nstream\n";
     iStream.putRaw(deflated.data(), deflatedSize);
@@ -626,15 +672,21 @@ void PdfWriter::embedBitmaps(const BitmapFinder &bm)
 
 void PdfWriter::createResources(const BitmapFinder &bm)
 {
-  iStream << "/Resources <<\n  /ProcSet [ /PDF ";
-  if (iResourceNum >= 0)
+  // These are only the resources needed by Ipe drawing directly.
+  // Resources used from inside text objects (e.g. by tikz)
+  // are stored inside the XObject resources.
+  // Font is only used inside XObject, no font resource needed on page
+  // Resources:
+  // ProcSet, ExtGState, ColorSpace, Pattern, Shading, XObject, Font
+  // not used now: Properties
+  // ProcSet
+  iStream << "/Resources <<\n  /ProcSet [/PDF";
+  if (iResources)
     iStream << "/Text";
   if (!bm.iBitmaps.empty())
-    iStream << "/ImageB /ImageC";
-  iStream << " ]\n";
-  if (iResourceNum >= 0)
-    iStream << "  /Font " << iResourceNum << " 0 R\n";
-  // embed resources for gradients
+    iStream << "/ImageB/ImageC";
+  iStream << "]\n";
+  // Shading
   if (iGradients.size()) {
     iStream << "  /Shading <<";
     for (std::map<int,int>::const_iterator it = iGradients.begin();
@@ -642,14 +694,21 @@ void PdfWriter::createResources(const BitmapFinder &bm)
       iStream << " /Grad" << it->first << " " << it->second << " 0 R";
     iStream << " >>\n";
   }
+  // ExtGState
   if (iExtGState >= 0)
     iStream << "  /ExtGState " << iExtGState << " 0 R\n";
-  // patterns
+  // ColorSpace
   if (iPatternNum >= 0) {
-    iStream << "  /ColorSpace << /PCS [/Pattern /DeviceRGB] >>\n";
-    iStream << "  /Pattern " << iPatternNum << " 0 R\n";
+    iStream << "  /ColorSpace << /PCS [/Pattern /DeviceRGB] ";
+    iStream << ">>\n";
   }
-  if (!bm.iBitmaps.empty() || !iSymbols.empty()) {
+  // Pattern
+  if (iPatternNum >= 0)
+    iStream << "  /Pattern " << iPatternNum << " 0 R\n";
+  // XObject
+  // TODO: Is "hasResource" here used correctly?
+  // From Tikz xobject resources seem to go into the Ipe xform.
+  if (!bm.iBitmaps.empty() || !iSymbols.empty() || hasResource("XObject")) {
     iStream << "  /XObject << ";
     for (BmIter it = bm.iBitmaps.begin(); it != bm.iBitmaps.end(); ++it) {
       // mention each PDF object only once
@@ -663,6 +722,7 @@ void PdfWriter::createResources(const BitmapFinder &bm)
     for (std::map<int,int>::const_iterator it = iSymbols.begin();
 	 it != iSymbols.end(); ++it)
       iStream << "/Symbol" << it->first << " " << it->second << " 0 R ";
+    embedResource("XObject");
     iStream << ">>\n";
   }
   iStream << "  >>\n";
@@ -680,7 +740,7 @@ void PdfWriter::paintView(Stream &stream, int pno, int view)
   if (background && page->findLayer("BACKGROUND") < 0)
     painter.drawSymbol(Attribute::BACKGROUND());
 
-  if (iDoc->properties().iNumberPages) {
+  if (iDoc->properties().iNumberPages && iResources) {
     const Text *pn = iResources->pageNumber(pno, view);
     if (pn)
       pn->draw(painter);
