@@ -77,6 +77,10 @@ static bool initialized = false;
 static bool showDebug = false;
 static Platform::DebugHandler debugHandler = nullptr;
 
+#ifdef IPEAPPIMAGE
+static String appImageBase;
+#endif
+
 #ifdef WIN32
 static ULONG_PTR gdiplusToken = 0;
 // not yet available in MINGW RT library
@@ -147,6 +151,13 @@ void Platform::initLib(int version)
     fprintf(stderr, "Debug messages enabled\n");
   }
   debugHandler = debugHandlerImpl;
+#ifdef IPEAPPIMAGE
+  const char *cwd = getcwd(nullptr, 0);
+  if (cwd)
+    appImageBase = cwd;
+  else
+    appImageBase = ".";
+#endif
 #ifdef WIN32
   readIpeConf();
   // ipeLocale = ::_create_locale(LC_NUMERIC, "C");
@@ -209,6 +220,14 @@ String Platform::currentDirectory()
 #ifdef IPEBUNDLE
 String Platform::ipeDir(const char *suffix, const char *fname)
 {
+#ifdef IPESNAPCRAFT
+  const char *p = getenv("SNAP");
+  String exe = p ? p : "/snap/ipe/current";
+  exe += "/ipe/";
+#else
+#ifdef IPEAPPIMAGE
+  String exe = appImageBase + "/ipe/";
+#else
 #ifdef WIN32
   wchar_t exename[OFS_MAXPATHNAME];
   GetModuleFileNameW(0, exename, OFS_MAXPATHNAME);
@@ -239,6 +258,8 @@ String Platform::ipeDir(const char *suffix, const char *fname)
     exe += "/Resources/";
 #else
   exe += IPESEP;
+#endif
+#endif
 #endif
   exe += suffix;
   if (fname) {
