@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -314,7 +314,7 @@ bool Reference::setAttribute(Property prop, Attribute value)
   return false;
 }
 
-Attribute Reference::getAttribute(Property prop)
+Attribute Reference::getAttribute(Property prop) const noexcept
 {
   switch (prop) {
   case EPropPen:
