@@ -57,7 +57,8 @@ using namespace ipe;
 
 class CollectSegs : public Visitor {
 public:
-  CollectSegs(const Vector &mouse, double snapDist, const Page *page);
+  CollectSegs(const Vector &mouse, double snapDist,
+	      const Page *page, int view);
 
   virtual void visitGroup(const Group *obj);
   virtual void visitPath(const Path *obj);
@@ -72,15 +73,16 @@ private:
   std::vector<Matrix> iMatrices;
   Vector iMouse;
   double iDist;
+  int iView;
 };
 
 CollectSegs::CollectSegs(const Vector &mouse, double snapDist,
-			 const Page *page)
-  : iMouse(mouse), iDist(snapDist)
+			 const Page *page, int view)
+  : iMouse(mouse), iDist(snapDist), iView(view)
 {
   iMatrices.push_back(Matrix()); // identity matrix
   for (int i = 0; i < page->count(); ++i) {
-    if (page->hasSnapping(page->layerOf(i)))
+    if (page->objSnapsInView(i, iView))
       page->object(i)->accept(*this);
   }
 }
@@ -162,7 +164,7 @@ void CollectSegs::visitPath(const Path *obj)
 
 /*! Find line through \a base with slope determined by angular snap
   size and direction. */
-Line Snap::getLine(const Vector &mouse, const Vector &base) const
+Line Snap::getLine(const Vector &mouse, const Vector &base) const noexcept
 {
   Angle alpha = iDir;
   Vector d = mouse - base;
@@ -177,9 +179,10 @@ Line Snap::getLine(const Vector &mouse, const Vector &base) const
 
 //! Perform intersection snapping.
 void Snap::intersectionSnap(const Vector &pos,  Vector &fifi,
-			    const Page *page, double &snapDist) const
+			    const Page *page, int view,
+			    double &snapDist) const noexcept
 {
-  CollectSegs segs(pos, snapDist, page);
+  CollectSegs segs(pos, snapDist, page, view);
 
   Vector v;
   std::vector<Vector> pts;
@@ -230,10 +233,10 @@ void Snap::intersectionSnap(const Vector &pos,  Vector &fifi,
 
 //! Perform snapping to intersection of angular line and pos.
 bool Snap::snapAngularIntersection(Vector &pos, const Line &l,
-				   const Page *page,
-				   double snapDist) const
+				   const Page *page, int view,
+				   double snapDist) const noexcept
 {
-  CollectSegs segs(pos, snapDist, page);
+  CollectSegs segs(pos, snapDist, page, view);
 
   std::vector<Vector> pts;
   Vector v;
@@ -272,8 +275,8 @@ bool Snap::snapAngularIntersection(Vector &pos, const Line &l,
 
 //! Tries vertex, intersection, boundary, and grid snapping.
 /*! If snapping occurred, \a pos is set to the new user space position. */
-Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page,
-				  double snapDist, Tool *tool) const
+Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page, int view,
+				  double snapDist, Tool *tool) const noexcept
 {
   double d = snapDist;
   Vector fifi = pos;
@@ -281,7 +284,7 @@ Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page,
   // highest priority: vertex snapping
   if (iSnap & ESnapVtx) {
     for (int i = 0; i < page->count(); ++i) {
-      if (page->hasSnapping(page->layerOf(i)))
+      if (page->objSnapsInView(i, view))
 	page->snapVtx(i, pos, fifi, d);
     }
     if (tool)
@@ -292,7 +295,7 @@ Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page,
   Vector fifiCtl = pos;
   if (iSnap & ESnapCtl) {
     for (int i = 0; i < page->count(); ++i) {
-      if (page->hasSnapping(page->layerOf(i)))
+      if (page->objSnapsInView(i, view))
 	page->snapCtl(i, pos, fifiCtl, d);
     }
     if (tool)
@@ -302,7 +305,7 @@ Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page,
   double dctl = d;
   Vector fifiX = pos;
   if (iSnap & ESnapInt)
-    intersectionSnap(pos, fifiX, page, d);
+    intersectionSnap(pos, fifiX, page, view, d);
 
   // Return if snapping has occurred
   if (d < dctl) {
@@ -319,7 +322,7 @@ Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page,
   // boundary snapping
   if (iSnap & ESnapBd) {
     for (int i = 0; i < page->count(); ++i) {
-      if (page->hasSnapping(page->layerOf(i)))
+      if (page->objSnapsInView(i, view))
 	page->snapBnd(i, pos, fifi, d);
     }
     if (d < snapDist) {
@@ -346,8 +349,9 @@ Snap::TSnapModes Snap::simpleSnap(Vector &pos, const Page *page,
   Automatic angular snapping occurs if \a autoOrg is not null --- the
   value is then used as the origin for automatic angular snapping.
 */
-Snap::TSnapModes Snap::snap(Vector &pos, const Page *page, double snapDist,
-			    Tool *tool, Vector *autoOrg) const
+Snap::TSnapModes Snap::snap(Vector &pos, const Page *page, int view,
+			    double snapDist, Tool *tool,
+			    Vector *autoOrg) const noexcept
 {
   // automatic angular snapping and angular snapping both on?
   if (autoOrg && (iSnap & ESnapAuto) && (iSnap & ESnapAngle)) {
@@ -372,21 +376,21 @@ Snap::TSnapModes Snap::snap(Vector &pos, const Page *page, double snapDist,
     Line l = getLine(pos, org);
     pos = l.project(pos);
     if (iSnap & ESnapBd)
-      snapAngularIntersection(pos, l, page, snapDist);
+      snapAngularIntersection(pos, l, page, view, snapDist);
     return ESnapAngle;
   }
 
   // we are not in any angular snapping mode
-  return simpleSnap(pos, page, snapDist, tool);
+  return simpleSnap(pos, page, view, snapDist, tool);
 }
 
 //! Set axis origin and direction from edge near mouse.
 /*! Returns \c true if successful. */
-bool Snap::setEdge(const Vector &pos, const Page *page)
+bool Snap::setEdge(const Vector &pos, const Page *page, int view) noexcept
 {
   // bound cannot be too small, as distance to Bezier
   // is computed based on an approximation of precision 1.0
-  CollectSegs segs(pos, 2.0, page);
+  CollectSegs segs(pos, 2.0, page, view);
 
   if (!segs.iSegs.empty()) {
     Segment seg = segs.iSegs.back();
