@@ -176,7 +176,7 @@ void StyleSheet::setPageNumberStyle(const PageNumberStyle &pns)
 }
 
 //! Return page number style.
-const StyleSheet::PageNumberStyle *StyleSheet::pageNumberStyle()
+const StyleSheet::PageNumberStyle *StyleSheet::pageNumberStyle() const
 {
   if (iPageNumberStyle.iDefined)
     return &iPageNumberStyle;
@@ -457,11 +457,14 @@ void StyleSheet::saveAsXml(Stream &stream, bool saveBitmaps) const
 
   for (Map::const_iterator it = iMap.begin(); it != iMap.end(); ++it) {
     int kind = (it->first >> SHIFT);
-    stream << "<" << kind_names[kind]
+    int kind1 = (kind == ELabelStyle) ? ETextStyle : kind;
+    stream << "<" << kind_names[kind1]
 	   << " name=\"" << rep->toString(it->first & MASK) << "\"";
-    if (kind == ETextStyle) {
+    if (kind1 == ETextStyle) {
       String s = it->second.string();
       int i = s.find('\0');
+      if (kind == ELabelStyle)
+	stream << " type=\"label\"";
       stream << " begin=\"" << s.substr(0, i) << "\" end=\""
 	     << s.substr(i+1) << "\"/>\n";
     } else
