@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -82,16 +82,18 @@ Text::Text(const AllAttributes &attr, String data,
   iStroke = attr.iStroke;
   iOpacity = attr.iOpacity;
   iSize = attr.iTextSize;
-  iStyle = attr.iTextStyle;
   iPos = pos;
   iType = type;
   iWidth = width;
   iHeight = 10.0;
   iDepth = 0.0;
-  if (iType == ELabel)
+  if (iType == ELabel) {
+    iStyle = attr.iLabelStyle;
     iVerticalAlignment = attr.iVerticalAlignment;
-  else
+  } else {
+    iStyle = attr.iTextStyle;
     iVerticalAlignment = EAlignTop;
+  }
   iHorizontalAlignment = attr.iHorizontalAlignment;
   if (!attr.iTransformableText)
     // override setting
@@ -174,6 +176,12 @@ Text::Text(const XmlAttributes &attr, String data)
     iOpacity = Attribute(true, str);
   else
     iOpacity = Attribute::OPAQUE();
+
+  if (iType == ELabel && iStyle == Attribute::NORMAL() &&
+      iText.size() >= 3 && iText[0] == '$' && iText[iText.size()-1] == '$') {
+    iStyle = Attribute(true, "math");
+    iText = iText.substr(1, iText.size() - 2);
+  }
 }
 
 // --------------------------------------------------------------------
@@ -408,7 +416,7 @@ void Text::setSize(Attribute size)
 void Text::setStyle(Attribute style)
 {
   iStyle = style;
-  setXForm(0);
+  setXForm(nullptr);
 }
 
 //! Sets the text of the text object.
@@ -416,13 +424,18 @@ void Text::setStyle(Attribute style)
 void Text::setText(String text)
 {
   iText = text;
-  setXForm(0);
+  setXForm(nullptr);
 }
 
 //! Change type.
+/*! This invalidates (and destroys) the XForm. */
 void Text::setTextType(TextType type)
 {
-  iType = type;
+  if (type != iType) {
+    iType = type;
+    iStyle = Attribute::NORMAL();
+    setXForm(nullptr);
+  }
 }
 
 //! Change horizontal alignment (text moves with respect to reference point).
@@ -453,7 +466,8 @@ bool Text::setAttribute(Property prop, Attribute value)
     }
     break;
   case EPropTextStyle:
-    if (!isMinipage() || value == style())
+  case EPropLabelStyle:
+    if ((isMinipage() != (prop == EPropTextStyle)) || value == style())
       return false;
     setStyle(value);
     return true;
@@ -481,6 +495,7 @@ bool Text::setAttribute(Property prop, Attribute value)
     assert(value.isEnum());
     if (value.boolean() != isMinipage()) {
       iType = value.boolean() ? EMinipage : ELabel;
+      iStyle = Attribute::NORMAL();
       return true;
     }
     break;
@@ -508,7 +523,7 @@ bool Text::setAttribute(Property prop, Attribute value)
   return false;
 }
 
-Attribute Text::getAttribute(Property prop)
+Attribute Text::getAttribute(Property prop) const noexcept
 {
   switch (prop) {
   case EPropStrokeColor:
@@ -516,6 +531,7 @@ Attribute Text::getAttribute(Property prop)
   case EPropTextSize:
     return size();
   case EPropTextStyle:
+  case EPropLabelStyle:
     return style();
   case EPropOpacity:
     return opacity();
@@ -539,7 +555,7 @@ void Text::checkStyle(const Cascade *sheet, AttributeSeq &seq) const
 {
   checkSymbol(EColor, iStroke, sheet, seq);
   checkSymbol(ETextSize, iSize, sheet, seq);
-  checkSymbol(ETextStyle, iStyle, sheet, seq);
+  checkSymbol((iType == ELabel ? ELabelStyle : ETextStyle), iStyle, sheet, seq);
   checkSymbol(EOpacity, iOpacity, sheet, seq);
 }
 
