@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -320,7 +320,7 @@ A85Source::A85Source(DataSource &source)
 int A85Source::getChar()
 {
   if (iIndex < iN)
-    return iBuf[iIndex++];
+    return uchar(iBuf[iIndex++]);
 
   if (iEof)
     return EOF;
@@ -341,7 +341,7 @@ int A85Source::getChar()
 
   if (ch == 'z') {
     iBuf[0] = iBuf[1] = iBuf[2] = iBuf[3] = 0;
-    return iBuf[0];
+    return uchar(iBuf[0]);
   }
 
   int c[5];
@@ -412,7 +412,7 @@ int Base64Source::getChar()
     return EOF;
 
   if (iIndex < iBufLen)
-    return iBuf[iIndex++];
+    return uchar(iBuf[iIndex++]);
 
   char buf[4];
   for (int i = 0; i < 4; ++i) {
@@ -446,7 +446,7 @@ int Base64Source::getChar()
       --iBufLen;
   }
   iIndex = 1;
-  return iBuf[0];
+  return uchar(iBuf[0]);
 };
 
 // --------------------------------------------------------------------
@@ -628,7 +628,7 @@ int InflateSource::getChar()
 
   z_streamp z = &iPriv->iFlate;
   if (iP < (char *) z->next_out)
-    return *iP++;
+    return uchar(*iP++);
 
   // next to decompress some data
   if (z->avail_in == 0)
@@ -648,7 +648,7 @@ int InflateSource::getChar()
     }
     iP = iOut.data();
     if (iP < (char *) z->next_out)
-      return *iP++;
+      return uchar(*iP++);
     // didn't get any new data, must be EOF
   }
 
