@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -268,35 +268,6 @@ static int document_countTotalViews(lua_State *L)
   return 1;
 }
 
-// Document --> boolean
-static int document_has(lua_State *L)
-{
-  static const char * const what_names[] =
-    { "truetype", "gradients", "tilings", "transparency", 0 };
-
-  Document **d = check_document(L, 1);
-  int what = luaL_checkoption(L, 2, 0, what_names);
-  bool result = false;
-  switch (what) {
-  case 0: //
-    result = (*d)->hasTrueTypeFonts();
-    break;
-  case 1:
-    result = (*d)->hasGradients();
-    break;
-  case 2:
-    result = (*d)->hasTilings();
-    break;
-  case 3:
-    result = (*d)->hasTransparency();
-    break;
-  default:
-    break;
-  }
-  lua_pushboolean(L, result);
-  return 1;
-}
-
 static int document_sheets(lua_State *L)
 {
   Document **d = check_document(L, 1);
@@ -358,11 +329,6 @@ static int document_runLatex(lua_State *L)
       lua_pushliteral(L, "There was an error reading the Pdflatex output");
       lua_pushliteral(L, "latexoutput");
       break;
-    case Document::ErrNoIconv:
-      lua_pushliteral(L, "This document needs charset conversion to run "
-		      "Pdflatex, but Ipe is compiled without this feature");
-      lua_pushliteral(L, "noiconv");
-      break;
     }
   }
   push_string(L, log);
@@ -418,6 +384,9 @@ static int document_remove(lua_State *L)
   return 1;
 }
 
+static const char * const tex_engine_names[] = {
+  "default", "pdftex", "xetex", "luatex" };
+
 static int document_properties(lua_State *L)
 {
   Document **d = check_document(L, 1);
@@ -443,6 +412,8 @@ static int document_properties(lua_State *L)
   lua_setfield(L, -2, "fullscreen");
   lua_pushboolean(L, prop.iNumberPages);
   lua_setfield(L, -2, "numberpages");
+  lua_pushstring(L, tex_engine_names[int(prop.iTexEngine)]);
+  lua_setfield(L, -2, "tex");
   return 1;
 }
 
@@ -478,6 +449,12 @@ static int document_setProperties(lua_State *L)
   propString(L, "created", prop.iCreated);
   propString(L, "modified", prop.iModified);
   propString(L, "creator", prop.iCreator);
+  String tex;
+  propString(L, "tex", tex);
+  for (int i = 0; i < 4; ++i) {
+    if (!strcmp(tex.z(), tex_engine_names[i]))
+      prop.iTexEngine = LatexType(i);
+  }
   (*d)->setProperties(prop);
   return 0;
 }
@@ -500,7 +477,6 @@ static const struct luaL_Reg document_methods[] = {
   { "countTotalViews", document_countTotalViews },
   { "sheets", document_sheets },
   { "replaceSheets", document_replaceSheets },
-  { "has", document_has },
   { "runLatex", document_runLatex },
   { "checkStyle", document_checkStyle },
   { "properties", document_properties },
