@@ -229,8 +229,10 @@ Attribute ipelua::check_property(Property prop, lua_State *L, int i)
   case EPropRArrowShape:
   case EPropMarkShape:
   case EPropTextStyle:
+  case EPropLabelStyle:
   case EPropOpacity:
   case EPropGradient:
+  case EPropDecoration:
   case EPropTiling:  // symbolic string only
     return Attribute(true, luaL_checkstring(L, i));
   case EPropStrokeColor:
@@ -295,6 +297,7 @@ void ipelua::check_allattributes(lua_State *L, int i, AllAttributes &all)
   get_attribute(L, i, EPropTextSize, "textsize", all.iTextSize);
   get_boolean(L, i, "transformabletext", all.iTransformableText);
   get_attribute(L, i, EPropTextStyle, "textstyle", all.iTextStyle);
+  get_attribute(L, i, EPropTextStyle, "labelstyle", all.iLabelStyle);
   get_attribute(L, i, EPropOpacity, "opacity", all.iOpacity);
   get_attribute(L, i, EPropTiling, "tiling", all.iTiling);
   get_attribute(L, i, EPropGradient, "gradient", all.iGradient);
@@ -548,6 +551,28 @@ static int object_elements(lua_State *L)
   return 1;
 }
 
+static int object_element(lua_State *L)
+{
+  Object *obj = check_object(L, 1)->obj;
+  luaL_argcheck(L, obj->type() == Object::EGroup, 1, "not a group object");
+  int idx = (int) luaL_checkinteger(L, 2);
+  Group *g = obj->asGroup();
+  luaL_argcheck(L, 1 <= idx && idx <= g->count(), 2, "incorrect element index");
+  push_object(L, g->object(idx-1)->clone());
+  return 1;
+}
+
+static int object_elementType(lua_State *L)
+{
+  Object *obj = check_object(L, 1)->obj;
+  luaL_argcheck(L, obj->type() == Object::EGroup, 1, "not a group object");
+  int idx = (int) luaL_checkinteger(L, 2);
+  Group *g = obj->asGroup();
+  luaL_argcheck(L, 1 <= idx && idx <= g->count(), 2, "incorrect element index");
+  lua_pushstring(L, type_names[g->object(idx-1)->type()]);
+  return 1;
+}
+
 static int object_xml(lua_State *L)
 {
   SObject *obj = check_object(L, 1);
@@ -880,6 +905,8 @@ static const struct luaL_Reg object_methods[] = {
   { "text", object_text },
   { "setText", object_setText },
   { "elements", object_elements },
+  { "element", object_element },
+  { "elementType", object_elementType },
   { NULL, NULL }
 };
 
