@@ -624,9 +624,10 @@ static int page_setVisible(lua_State *L)
 static int page_findedge(lua_State *L)
 {
   Page *p = check_page(L, 1)->page;
-  Vector pos = *check_vector(L, 2);
+  int view = check_viewno(L, 2, p, 0);
+  Vector pos = *check_vector(L, 3);
   Snap snap;
-  if (!snap.setEdge(pos, p))
+  if (!snap.setEdge(pos, p, view))
     return 0;
   push_vector(L, snap.iOrigin);
   lua_pushnumber(L, snap.iDir);
