@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -65,7 +65,8 @@ static int renderPage(Thumbnail::TargetFormat fm,
 
   Thumbnail tn(doc, 0);
   const Page *page = doc->page(pageNum - 1);
-  tn.saveRender(fm, dst, page, viewNum - 1, zoom, transparent, nocrop);
+  if (!tn.saveRender(fm, dst, page, viewNum - 1, zoom, transparent, nocrop))
+    fprintf(stderr, "Failure to render page.\n");
   delete doc;
   return 0;
 }
