@@ -37,6 +37,12 @@
 using namespace ipe;
 using namespace ipelua;
 
+#ifdef WIN32
+#define IPEPATHSEP (';')
+#else
+#define IPEPATHSEP (':')
+#endif
+
 // --------------------------------------------------------------------
 
 static int traceback (lua_State *L)
@@ -90,34 +96,42 @@ static void setup_globals(lua_State *L)
     int i = 0;
     while (i < scripts.size()) {
       int j = i;
-      while (i < scripts.size() && scripts[i] != ';' && scripts[i] != ':')
+      while (i < scripts.size() && scripts[i] != IPEPATHSEP)
 	i += 1;
       String d = scripts.substr(j, i-j);
       if (d == "_")
 #ifdef IPEBUNDLE
-	d = Platform::ipeDir("scripts", "?.lua");
+	d = Platform::ipeDir("scripts", nullptr);
 #else
 	d = IPESCRIPTDIR;
 #endif
       d += "/?.lua";
       if (!s.empty())
-	s += ";";
+	s += ';';
       s += d;
       i += 1;
     }
+    ipeDebug("package.path = %s", s.z());
     lua_pushstring(L, s.z());
   } else {
     String s = "./?.lua;";
-#ifdef IPEBUNDLE
-    s += Platform::ipeDir("scripts", "?.lua");
-#else
+#ifndef WIN32
     const char *home = getenv("HOME");
     if (home) {
       s += home;
       s += "/.ipe/scripts/?.lua;";
+#ifdef __APPLE__
+      s += home;
+      s += "/Library/Ipe/Scripts/?.lua;";
+#endif
     }
+#endif
+#ifdef IPEBUNDLE
+    s += Platform::ipeDir("scripts", "?.lua");
+#else
     s += IPESCRIPTDIR "/?.lua";
 #endif
+    ipeDebug("package.path = %s", s.z());
     lua_pushstring(L, s.z());
   }
   lua_setfield(L, -2, "path");
