@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -180,9 +180,9 @@ int main(int argc, char *argv[])
     }
   }
 
-  IpeAutoPtr<Document> doc(Document::loadWithErrorReport(infile.z()));
+  std::unique_ptr<Document> doc(Document::loadWithErrorReport(infile.z()));
 
-  if (!doc.ptr())
+  if (!doc)
     return 1;
 
   fprintf(stderr, "Document %s has %d pages (%d views)\n",
@@ -218,14 +218,14 @@ int main(int argc, char *argv[])
   switch (frm) {
   case Document::EXml:
     if (runLatex)
-      return topdf(doc.ptr(), infile, outfile, Document::EXml, flags);
+      return topdf(doc.get(), infile, outfile, Document::EXml, flags);
     else
       doc->save(outfile.z(), Document::EXml, Document::ESaveNormal);
   default:
     return 0;
 
   case Document::EPdf:
-    return topdf(doc.ptr(), infile, outfile, Document::EPdf,
+    return topdf(doc.get(), infile, outfile, Document::EPdf,
 		 flags, fromPage, toPage, viewNo);
   }
 }
