@@ -501,6 +501,9 @@ void PDialog::layoutControls()
     layout(lastButton, content, "l=l", buttonGap);
   else if (bcount)
     layout(lastButton, content, "l>l", buttonGap);
+  else
+    // no button added using "addButton".  Probably an old ipelet.
+    layout(content, rows[iNoRows-1], "b=b", gap);
 
   while (int(iColStretch.size()) < iNoCols)
     iColStretch.push_back(0);
