@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 */
 
 #include "ipeui_common.h"
+#include <algorithm>
 
 // --------------------------------------------------------------------
 
@@ -62,58 +63,6 @@ static const struct luaL_Reg winid_methods[] = {
 
 // --------------------------------------------------------------------
 
-String::String()
-{
-  iImp = 0;
-}
-
-String::String(const String &rhs)
-{
-  iImp = rhs.iImp;
-  if (iImp)
-    iImp->iRefCount += 1;
-}
-
-String::String(const char *str)
-{
-  if (str) {
-    iImp = new Imp;
-    iImp->iRefCount = 1;
-    iImp->iData = strdup(str);
-  } else
-    iImp = 0;
-}
-
-String &String::operator=(const String &rhs)
-{
-  if (this != &rhs) {
-    if (iImp) {
-      iImp->iRefCount -= 1;
-      if (iImp->iRefCount == 0) {
-	free(iImp->iData);
-	delete iImp;
-      }
-    }
-    iImp = rhs.iImp;
-    if (iImp)
-      iImp->iRefCount += 1;
-  }
-  return *this;
-}
-
-String::~String()
-{
-  if (iImp) {
-    iImp->iRefCount -= 1;
-    if (iImp->iRefCount == 0) {
-      free(iImp->iData);
-      delete iImp;
-    }
-  }
-}
-
-// --------------------------------------------------------------------
-
 Dialog::Dialog(lua_State *L0, WINID parent, const char *caption)
   : iCaption(caption)
 {
@@ -149,7 +98,7 @@ void Dialog::callLua(int luaMethod)
 int Dialog::addButton(lua_State *L)
 {
   SElement m;
-  m.name = String(luaL_checkstring(L, 2));
+  m.name = std::string(luaL_checkstring(L, 2));
   m.type = EButton;
   m.lua_method = LUA_NOREF;
   m.flags = 0;
@@ -157,7 +106,7 @@ int Dialog::addButton(lua_State *L)
   m.col = -1;
   m.rowspan = 1;
   m.colspan = 1;
-  m.text = String(luaL_checkstring(L, 3));
+  m.text = std::string(luaL_checkstring(L, 3));
   if (lua_isstring(L, 4)) {
     const char *s = lua_tostring(L, 4);
     if (!strcmp(s, "accept"))
@@ -172,7 +121,7 @@ int Dialog::addButton(lua_State *L)
     m.lua_method = luaL_ref(L, LUA_REGISTRYINDEX);
   }
   m.minHeight = 16;
-  m.minWidth = 4 * m.text.len() + 8;
+  m.minWidth = 4 * m.text.length() + 8;
   if (m.minWidth < 64)
     m.minWidth = 64;
   iElements.push_back(m);
@@ -185,12 +134,14 @@ int Dialog::add(lua_State *L)
     { "button", "text", "list", "label", "combo", "checkbox", "input", 0 };
 
   SElement m;
-  m.name = String(luaL_checkstring(L, 2));
+  m.name = std::string(luaL_checkstring(L, 2));
   m.type = TType(luaL_checkoption(L, 3, 0, typenames));
   luaL_checktype(L, 4, LUA_TTABLE);
   m.lua_method = LUA_NOREF;
   m.flags = 0;
   m.row = (int)luaL_checkinteger(L, 5) - 1;
+  if (m.row < 0)
+    m.row = iNoRows + 1 + m.row;
   m.col = (int)luaL_checkinteger(L, 6) - 1;
   m.rowspan = 1;
   m.colspan = 1;
@@ -236,10 +187,10 @@ void Dialog::addLabel(lua_State *L, SElement &m)
 {
   lua_getfield(L, 4, "label");
   luaL_argcheck(L, lua_isstring(L, -1), 4, "no label");
-  m.text = String(lua_tostring(L, -1));
+  m.text = std::string(lua_tostring(L, -1));
   lua_pop(L, 1); // label
   m.minHeight = 16;
-  const char *p = m.text.z();
+  const char *p = m.text.c_str();
   int maxlen = 0;
   int curlen = 0;
   while (*p) {
@@ -261,7 +212,7 @@ void Dialog::addButtonItem(lua_State *L, SElement &m)
   lua_getfield(L, 4, "label");
   luaL_argcheck(L, lua_isstring(L, -1), 4, "no button label");
   const char *label = lua_tostring(L, -1);
-  m.text = String(label);
+  m.text = std::string(label);
   lua_getfield(L, 4, "action");
   if (lua_isstring(L, -1)) {
     const char *s = lua_tostring(L, -1);
@@ -278,7 +229,7 @@ void Dialog::addButtonItem(lua_State *L, SElement &m)
     luaL_argerror(L, 4, "unknown action type");
   lua_pop(L, 2); // action, label
   m.minHeight = 16;
-  m.minWidth = 4 * m.text.len() + 8;
+  m.minWidth = 4 * m.text.length() + 8;
   if (m.minWidth < 64)
     m.minWidth = 64;
 }
@@ -287,7 +238,7 @@ void Dialog::addCheckbox(lua_State *L, SElement &m)
 {
   lua_getfield(L, 4, "label");
   luaL_argcheck(L, lua_isstring(L, -1), 4, "no label");
-  m.text = String(lua_tostring(L, -1));
+  m.text = std::string(lua_tostring(L, -1));
   lua_getfield(L, 4, "action");
   if (!lua_isnil(L, -1)) {
     luaL_argcheck(L, lua_isfunction(L, -1), 4, "unknown action type");
@@ -297,7 +248,7 @@ void Dialog::addCheckbox(lua_State *L, SElement &m)
   lua_pop(L, 2); // action, label
   m.value = 0;
   m.minHeight = 16;
-  m.minWidth = 4 * m.text.len() + 32;
+  m.minWidth = 4 * m.text.length() + 32;
 }
 
 void Dialog::addInput(lua_State *L, SElement &m)
@@ -336,7 +287,10 @@ void Dialog::addTextEdit(lua_State *L, SElement &m)
     } else
       luaL_argerror(L, 4, "unknown syntax");
   }
-  lua_pop(L, 4); // syntax, focus, select_all, read_only
+  lua_getfield(L, 4, "spell_check");
+  if (lua_toboolean(L, -1))
+    m.flags |= ESpellCheck;
+  lua_pop(L, 5); // spell_check, syntax, focus, select_all, read_only
   m.minHeight = 48;
   m.minWidth = 100;
 }
@@ -349,7 +303,7 @@ void Dialog::setListItems(lua_State *L, int index, SElement &m)
     lua_rawgeti(L, index, i);
     luaL_argcheck(L, lua_isstring(L, -1), index, "items must be strings");
     const char *item = lua_tostring(L, -1);
-    m.items.push_back(String(item));
+    m.items.emplace_back(item);
     int w = 4 * strlen(item) + 16;
     if (w > m.minWidth)
       m.minWidth = w;
@@ -375,7 +329,7 @@ int Dialog::findElement(lua_State *L, int index)
 {
   const char *name = luaL_checkstring(L, index);
   for (int i = 0; i < int(iElements.size()); ++i) {
-    if (!strcmp(iElements[i].name.z(), name))
+    if (!strcmp(iElements[i].name.c_str(), name))
       return i;
   }
   return luaL_argerror(L, index, "no such element in dialog");
@@ -407,7 +361,7 @@ void Dialog::setUnmapped(lua_State *L, int idx)
   case ELabel:
   case ETextEdit:
   case EInput:
-    m.text = String(luaL_checkstring(L, 3));
+    m.text = std::string(luaL_checkstring(L, 3));
     break;
   case EList:
   case ECombo:
@@ -416,6 +370,13 @@ void Dialog::setUnmapped(lua_State *L, int idx)
       luaL_argcheck(L, 1 <= n && n <= int(m.items.size()), 3,
 		    "list index out of bounds");
       m.value = n - 1;
+    } else if (lua_isstring(L, 3)) {
+      const char *s = lua_tostring(L, 3);
+      auto it = std::find_if(m.items.cbegin(), m.items.cend(),
+			     [s](const std::string &el)
+			     { return !strcmp(el.c_str(), s); });
+      luaL_argcheck(L, it != m.items.end(), 3, "item not in list");
+      m.value = (it - m.items.begin());
     } else {
       luaL_checktype(L, 3, LUA_TTABLE);
       m.items.clear();
@@ -442,7 +403,7 @@ int Dialog::get(lua_State *L)
   switch (m.type) {
   case ETextEdit:
   case EInput:
-    lua_pushstring(L, m.text.z());
+    lua_pushstring(L, m.text.c_str());
     return 1;
   case EList:
   case ECombo:
@@ -673,7 +634,7 @@ void Timer::callLua()
     lua_pop(L, 2); // pop weak table, nil
     return;
   }
-  lua_getfield(L, -1, iMethod.z());
+  lua_getfield(L, -1, iMethod.c_str());
   if (lua_isnil(L, -1)) {
     lua_pop(L, 3); // pop weak table, table, nil
     return;
@@ -685,8 +646,7 @@ void Timer::callLua()
 
 int Timer::setSingleShot(lua_State *L)
 {
-  bool t = lua_toboolean(L, 2);
-  iSingleShot = t;
+  iSingleShot = lua_toboolean(L, 2);
   return 0;
 }
 
