@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -41,22 +41,27 @@ extern "C" {
 #include <cstdlib>
 #include <cstring>
 #include <vector>
+#include <string>
 
 #ifdef IPEUI_GTK
 #include <gtk/gtk.h>
-typedef GtkWidget *WINID;
+using WINID = GtkWidget *;
 #endif
 #ifdef IPEUI_WIN32
 #include <windows.h>
-typedef HWND WINID;
+using WINID = HWND;
 #endif
 #ifdef IPEUI_QT
 #include <QWidget>
-typedef QWidget *WINID;
+using WINID = QWidget *;
+#endif
+#ifdef IPEUI_COCOA
+#include <Cocoa/Cocoa.h>
+using WINID = NSWindow * __unsafe_unretained;
 #endif
 
-typedef unsigned short ushort;
-typedef unsigned char uchar;
+using ushort = unsigned short;
+using uchar = unsigned char;
 
 // --------------------------------------------------------------------
 
@@ -65,27 +70,6 @@ extern void push_winid(lua_State *L, WINID win);
 
 // --------------------------------------------------------------------
 
-class String {
-public:
-  String();
-  explicit String(const char *str);
-  String(const String &rhs);
-  String &operator=(const String &rhs);
-  ~String();
-  int len() const { return iImp ? strlen(iImp->iData) : 0; }
-  const char *z() const { return iImp ? iImp->iData : ""; }
-  operator const char *() const { return z(); }
-  int unicode(int &index) const;
-private:
-  struct Imp {
-    int iRefCount;
-    char *iData;
-  };
-  Imp *iImp;
-};
-
-// --------------------------------------------------------------------
-
 class Dialog {
 public:
   Dialog(lua_State *L0, WINID parent, const char *caption);
@@ -108,20 +92,21 @@ protected:
   enum TFlags { ELogFile = 0x001, EXml = 0x002, ELatex = 0x040,
 		EAccept = 0x004, EReject = 0x008,
 		EReadOnly = 0x010, EDisabled = 0x020,
-		ESelectAll = 0x080, EFocused = 0x100
+		ESelectAll = 0x080, EFocused = 0x100,
+		ESpellCheck = 0x200,
   };
   enum TType { EButton = 0, ETextEdit, EList, ELabel, ECombo,
 	       ECheckBox, EInput };
 
   struct SElement {
-    String name;
+    std::string name;
     TType type;
     int row, col, rowspan, colspan;
     int minWidth, minHeight;  // only used on Windows
     int lua_method;
     int flags;
-    std::vector<String> items;
-    String text;
+    std::vector<std::string> items;
+    std::string text;
     int value;
   };
 
@@ -150,7 +135,7 @@ protected:
   lua_State *L;
   WINID iParent;
   WINID hDialog;
-  String iCaption;
+  std::string iCaption;
   std::vector<SElement> iElements;
   int iLuaDialog;
   bool iIgnoreEscape;
@@ -202,7 +187,7 @@ protected:
 protected:
   lua_State *L;
   int iLuaObject;
-  String iMethod;
+  std::string iMethod;
   bool iSingleShot;
 };
 
