@@ -369,6 +369,8 @@ bool PDialog::buildAndRun(int w, int h)
       gridlayout()->addWidget(w, m.row, m.col, m.rowspan, m.colspan);
       if (m.flags & EFocused)
 	w->setFocus(Qt::OtherFocusReason);
+      if (m.flags & EDisabled)
+	w->setEnabled(false);
     }
   }
   setMinimumSize(w, h);
@@ -384,12 +386,11 @@ void PDialog::retrieveValues()
     QWidget *w = iWidgets[i];
     switch (m.type) {
     case EInput:
-      m.text = std::move(std::string((qobject_cast<QLineEdit *>(w))->
-				     text().toUtf8()));
+      m.text = std::string((qobject_cast<QLineEdit *>(w))->text().toUtf8());
       break;
     case ETextEdit:
-      m.text = std::move(std::string((qobject_cast<QTextEdit *>(w))->
-				     toPlainText().toUtf8()));
+      m.text = std::string((qobject_cast<QTextEdit *>(w))->
+			   toPlainText().toUtf8());
       break;
     case EList:
       {
