@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2015  Otfried Cheong
+    Copyright (C) 1993-2016  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -79,12 +79,12 @@ void sendMessage(HWND h, UINT code, const char *t, WPARAM wParam)
   SendMessageW(h, code, wParam, (LPARAM) w.data());
 }
 
-static String wideToUtf8(const wchar_t *wbuf)
+static std::string wideToUtf8(const wchar_t *wbuf)
 {
   int rm = WideCharToMultiByte(CP_UTF8, 0, wbuf, -1, NULL, 0, NULL, NULL);
-  char multi[rm];
-  WideCharToMultiByte(CP_UTF8, 0, wbuf, -1, multi, rm, NULL, NULL);
-  return String(multi);
+  std::vector<char> multi(rm);
+  WideCharToMultiByte(CP_UTF8, 0, wbuf, -1, &multi[0], rm, NULL, NULL);
+  return std::string(&multi[0]);
 }
 
 static void buildFlags(std::vector<short> &t, DWORD flags)
@@ -171,13 +171,13 @@ void PDialog::setMapped(lua_State *L, int idx)
   case ETextEdit:
   case EInput:
   case ELabel:
-    setWindowText(h, m.text);
+    setWindowText(h, m.text.c_str());
     break;
   case EList:
     if (!lua_isnumber(L, 3)) {
       ListBox_ResetContent(h);
       for (int j = 0; j < int(m.items.size()); ++j)
-	sendMessage(h, LB_ADDSTRING, m.items[j]);
+	sendMessage(h, LB_ADDSTRING, m.items[j].c_str());
     }
     ListBox_SetCurSel(h, m.value);
     break;
@@ -185,7 +185,7 @@ void PDialog::setMapped(lua_State *L, int idx)
     if (!lua_isnumber(L, 3)) {
       ComboBox_ResetContent(h);
       for (int j = 0; j < int(m.items.size()); ++j)
-	sendMessage(h, CB_ADDSTRING, m.items[j]);
+	sendMessage(h, CB_ADDSTRING, m.items[j].c_str());
     }
     ComboBox_SetCurSel(h, m.value);
     break;
@@ -198,9 +198,9 @@ void PDialog::setMapped(lua_State *L, int idx)
   }
 }
 
-static void markupLog(HWND h, String text)
+static void markupLog(HWND h, const std::string &text)
 {
-  const char *p = text.z();
+  const char *p = text.c_str();
   if (*p) ++p;
   int pos = 1;
   while (*p) {
@@ -235,7 +235,7 @@ BOOL PDialog::initDialog()
     switch (m.type) {
     case EInput:
     case ETextEdit:
-      setWindowText(h, m.text);
+      setWindowText(h, m.text.c_str());
       if (m.flags & EFocused) {
 	SetFocus(h);
 	result = FALSE; // we set the focus ourselves
@@ -245,12 +245,12 @@ BOOL PDialog::initDialog()
       break;
     case EList:
       for (int j = 0; j < int(m.items.size()); ++j)
-	sendMessage(h, LB_ADDSTRING, m.items[j]);
+	sendMessage(h, LB_ADDSTRING, m.items[j].c_str());
       ListBox_SetCurSel(h, m.value);
       break;
     case ECombo:
       for (int j = 0; j < int(m.items.size()); ++j)
-	sendMessage(h, CB_ADDSTRING, m.items[j]);
+	sendMessage(h, CB_ADDSTRING, m.items[j].c_str());
       ComboBox_SetCurSel(h, m.value);
       break;
     case ECheckBox:
@@ -264,11 +264,11 @@ BOOL PDialog::initDialog()
   return result;
 }
 
-static String getEditText(HWND h)
+static std::string getEditText(HWND h)
 {
   int n = GetWindowTextLengthW(h);
   if (n == 0)
-    return String("");
+    return std::string("");
   WCHAR wbuf[n+1];
   GetWindowTextW(h, wbuf, n+1);
   std::vector<wchar_t> w;
@@ -450,17 +450,17 @@ void PDialog::buildElements(std::vector<short> &t)
 	flags |= BS_PUSHBUTTON;
       buildFlags(t, flags);
       buildDimensions(t, m, id);
-      buildControl(t, 0x0080, m.text.z());  // button
+      buildControl(t, 0x0080, m.text.c_str());  // button
       break;
     case ECheckBox:
       buildFlags(t, flags|BS_AUTOCHECKBOX|BS_TEXT|WS_TABSTOP);
       buildDimensions(t, m, id);
-      buildControl(t, 0x0080, m.text.z());  // button
+      buildControl(t, 0x0080, m.text.c_str());  // button
       break;
     case ELabel:
       buildFlags(t, flags|SS_LEFT);
       buildDimensions(t, m, id);
-      buildControl(t, 0x0082, m.text.z());  // static text
+      buildControl(t, 0x0082, m.text.c_str());  // static text
       break;
     case EInput:
       buildFlags(t, flags|ES_LEFT|WS_TABSTOP|WS_BORDER|ES_AUTOHSCROLL);
@@ -516,7 +516,7 @@ bool PDialog::buildAndRun(int w, int h)
   // class
   t.push_back(0);
   // title
-  buildString(t, iCaption.z());
+  buildString(t, iCaption.c_str());
   // for DS_SHELLFONT
   t.push_back(10);
   buildString(t,"MS Shell Dlg");
@@ -657,8 +657,8 @@ public:
   virtual int execute(lua_State *L);
 private:
   struct Item {
-    String name;
-    String itemName;
+    std::string name;
+    std::string itemName;
     int itemIndex;
   };
   std::vector<Item> items;
@@ -692,10 +692,10 @@ int PMenu::execute(lua_State *L)
 			      vx, vy, 0, hwnd, NULL);
   if (1 <= result && result <= int(items.size())) {
     result -= 1;
-    lua_pushstring(L, items[result].name.z());
+    lua_pushstring(L, items[result].name.c_str());
     lua_pushinteger(L, items[result].itemIndex);
-    if (items[result].itemName.z())
-      lua_pushstring(L, items[result].itemName.z());
+    if (items[result].itemName.c_str())
+      lua_pushstring(L, items[result].itemName.c_str());
     else
       lua_pushstring(L, "");
     return 3;
@@ -732,7 +732,7 @@ int PMenu::add(lua_State *L)
   if (lua_gettop(L) == 3) {
     AppendMenuW(hMenu, MF_STRING, items.size() + 1, title);
     Item item;
-    item.name = String(name);
+    item.name = name;
     item.itemIndex = 0;
     items.push_back(item);
   } else {
@@ -773,8 +773,8 @@ int PMenu::add(lua_State *L)
       WString text(lua_tostring(L, -1));
       AppendMenuW(sm, MF_STRING, id, text);
       Item mitem;
-      mitem.name = String(name);
-      mitem.itemName = String(item);
+      mitem.name = name;
+      mitem.itemName = item;
       mitem.itemIndex = i;
       items.push_back(mitem);
       if (hascheck && !strcmp(item, current))
@@ -1032,8 +1032,8 @@ static int ipeui_fileDialog(lua_State *L)
   if (!result)
     return 0;
 
-  String s = wideToUtf8(ofn.lpstrFile);
-  lua_pushstring(L, s.z());
+  std::string s = wideToUtf8(ofn.lpstrFile);
+  lua_pushstring(L, s.c_str());
   lua_pushinteger(L, ofn.nFilterIndex);
   return 2;
 }
